# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cluster_manager.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cluster_manager.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63luster_manager.proto\"\x19\n\nStopPidMsg\x12\x0b\n\x03pid\x18\x01 \x01(\x05\"\x1a\n\x0b\x43heckPidMsg\x12\x0b\n\x03pid\x18\x01 \x01(\x05\"S\n\x13StartSparkServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"R\n\x12StopSparkServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"?\n\x14StartSparkServersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13StopSparkServersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"Y\n\x1dGetExecutionTimeSeriesDataMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x0f\n\x07minutes\x18\x03 \x01(\x05\"\xa1\x0b\n\x1d\x45mulationMetricsTimeSeriesDTO\x12\x33\n\x0e\x63lient_metrics\x18\x01 \x03(\x0b\x32\x1b.ClientPopulationMetricsDTO\x12\x30\n\x17\x61ggregated_docker_stats\x18\x02 \x03(\x0b\x32\x0f.DockerStatsDTO\x12+\n\x11\x64ocker_host_stats\x18\x03 \x03(\x0b\x32\x10.DockerStatsDict\x12&\n\x0chost_metrics\x18\x04 \x03(\x0b\x32\x10.HostMetricsDict\x12\x34\n\x17\x61ggregated_host_metrics\x18\x05 \x03(\x0b\x32\x13.HostMetricsDataDTO\x12\x35\n\x10\x64\x65\x66\x65nder_actions\x18\x06 \x03(\x0b\x32\x1b.EmulationDefenderActionDTO\x12\x35\n\x10\x61ttacker_actions\x18\x07 \x03(\x0b\x32\x1b.EmulationAttackerActionDTO\x12\x38\n\x15\x61gg_snort_ids_metrics\x18\x08 \x03(\x0b\x32\x19.SnortIdsAlertCountersDTO\x12\x14\n\x0c\x65mulation_id\x18\t \x01(\x05\x12=\n\x19ossec_host_alert_counters\x18\n \x03(\x0b\x32\x1a.OSSECIdsAlertCountersDict\x12G\n$aggregated_ossec_host_alert_counters\x18\x0b \x03(\x0b\x32\x19.OSSECIdsAlertCountersDTO\x12.\n\x13openflow_flow_stats\x18\x0c \x03(\x0b\x32\x11.FlowStatisticDTO\x12.\n\x13openflow_port_stats\x18\r \x03(\x0b\x32\x11.PortStatisticDTO\x12\x35\n\x17\x61vg_openflow_flow_stats\x18\x0e \x03(\x0b\x32\x14.AvgFlowStatisticDTO\x12\x35\n\x17\x61vg_openflow_port_stats\x18\x0f \x03(\x0b\x32\x14.AvgPortStatisticDTO\x12<\n openflow_flow_metrics_per_switch\x18\x10 \x03(\x0b\x32\x12.FlowStatisticDict\x12<\n openflow_port_metrics_per_switch\x18\x11 \x03(\x0b\x32\x12.PortStatisticDict\x12\x43\n$openflow_flow_avg_metrics_per_switch\x18\x12 \x03(\x0b\x32\x15.AvgFlowStatisticDict\x12\x43\n$openflow_port_avg_metrics_per_switch\x18\x13 \x03(\x0b\x32\x15.AvgPortStatisticDict\x12\x43\n$agg_openflow_flow_metrics_per_switch\x18\x14 \x03(\x0b\x32\x15.AggFlowStatisticDict\x12\x35\n\x17\x61gg_openflow_flow_stats\x18\x15 \x03(\x0b\x32\x14.AggFlowStatisticDTO\x12<\n\x1a\x61gg_snort_ids_rule_metrics\x18\x16 \x03(\x0b\x32\x18.SnortIdsRuleCountersDTO\x12:\n\x14snort_ids_ip_metrics\x18\x17 \x03(\x0b\x32\x1c.SnortIdsIpAlertCountersDict\x12=\n\x1asnort_rule_metrics_per_ids\x18\x18 \x03(\x0b\x32\x19.SnortIdsRuleCountersDict\x12?\n\x1bsnort_alert_metrics_per_ids\x18\x19 \x03(\x0b\x32\x1a.SnortIdsAlertCountersDict\"G\n\x14\x41vgPortStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x14.AvgPortStatisticDTO\"G\n\x14\x41ggFlowStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x14.AggFlowStatisticDTO\"G\n\x14\x41vgFlowStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x14.AvgFlowStatisticDTO\"A\n\x11PortStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x11.PortStatisticDTO\"A\n\x11\x46lowStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x11.FlowStatisticDTO\"Q\n\x19OSSECIdsAlertCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x19.OSSECIdsAlertCountersDTO\"A\n\x0fHostMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x13.HostMetricsDataDTO\"=\n\x0f\x44ockerStatsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x0f.DockerStatsDTO\"\xbc\x04\n\x13\x41vgPortStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\"\n\x1atotal_num_received_packets\x18\x03 \x01(\x03\x12 \n\x18total_num_received_bytes\x18\x04 \x01(\x03\x12!\n\x19total_num_received_errors\x18\x05 \x01(\x03\x12%\n\x1dtotal_num_transmitted_packets\x18\x06 \x01(\x03\x12#\n\x1btotal_num_transmitted_bytes\x18\x07 \x01(\x03\x12$\n\x1ctotal_num_transmitted_errors\x18\x08 \x01(\x03\x12\"\n\x1atotal_num_received_dropped\x18\t \x01(\x03\x12%\n\x1dtotal_num_transmitted_dropped\x18\n \x01(\x03\x12\'\n\x1ftotal_num_received_frame_errors\x18\x0b \x01(\x03\x12)\n!total_num_received_overrun_errors\x18\x0c \x01(\x03\x12%\n\x1dtotal_num_received_crc_errors\x18\r \x01(\x03\x12\x1c\n\x14total_num_collisions\x18\x0e \x01(\x03\x12 \n\x18\x61vg_duration_nanoseconds\x18\x0f \x01(\x03\x12\x1c\n\x14\x61vg_duration_seconds\x18\x10 \x01(\x03\"\x8f\x02\n\x13\x41vgFlowStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x19\n\x11total_num_packets\x18\x03 \x01(\x03\x12\x17\n\x0ftotal_num_bytes\x18\x04 \x01(\x03\x12 \n\x18\x61vg_duration_nanoseconds\x18\x05 \x01(\x03\x12\x1c\n\x14\x61vg_duration_seconds\x18\x06 \x01(\x03\x12\x18\n\x10\x61vg_hard_timeout\x18\x07 \x01(\x03\x12\x18\n\x10\x61vg_idle_timeout\x18\x08 \x01(\x03\x12\x14\n\x0c\x61vg_priority\x18\t \x01(\x03\x12\x12\n\navg_cookie\x18\n \x01(\x03\"\x8a\x01\n\x13\x41ggFlowStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x19\n\x11total_num_packets\x18\x03 \x01(\x03\x12\x17\n\x0ftotal_num_bytes\x18\x04 \x01(\x03\x12\x17\n\x0ftotal_num_flows\x18\x05 \x01(\x03\"\xf7\x03\n\x10PortStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x03\x12\x1c\n\x14num_received_packets\x18\x04 \x01(\x03\x12\x1a\n\x12num_received_bytes\x18\x05 \x01(\x03\x12\x1b\n\x13num_received_errors\x18\x06 \x01(\x03\x12\x1f\n\x17num_transmitted_packets\x18\x07 \x01(\x03\x12\x1d\n\x15num_transmitted_bytes\x18\x08 \x01(\x03\x12\x1e\n\x16num_transmitted_errors\x18\t \x01(\x03\x12\x1c\n\x14num_received_dropped\x18\n \x01(\x03\x12\x1f\n\x17num_transmitted_dropped\x18\x0b \x01(\x03\x12!\n\x19num_received_frame_errors\x18\x0c \x01(\x03\x12#\n\x1bnum_received_overrun_errors\x18\r \x01(\x03\x12\x1f\n\x17num_received_crc_errors\x18\x0e \x01(\x03\x12\x16\n\x0enum_collisions\x18\x0f \x01(\x03\x12\x1c\n\x14\x64uration_nanoseconds\x18\x10 \x01(\x03\x12\x18\n\x10\x64uration_seconds\x18\x11 \x01(\x03\"\xa4\x02\n\x10\x46lowStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x0f\n\x07in_port\x18\x03 \x01(\t\x12\x10\n\x08out_port\x18\x04 \x01(\t\x12\x17\n\x0f\x64st_mac_address\x18\x05 \x01(\t\x12\x13\n\x0bnum_packets\x18\x06 \x01(\x03\x12\x11\n\tnum_bytes\x18\x07 \x01(\x03\x12\x1c\n\x14\x64uration_nanoseconds\x18\x08 \x01(\x03\x12\x18\n\x10\x64uration_seconds\x18\t \x01(\x03\x12\x14\n\x0chard_timeout\x18\n \x01(\x03\x12\x14\n\x0cidle_timeout\x18\x0b \x01(\x03\x12\x10\n\x08priority\x18\x0c \x01(\x03\x12\x0e\n\x06\x63ookie\x18\r \x01(\x03\"\xc5\x01\n\x18OSSECIdsAlertCountersDTO\x12\x14\n\x0clevel_alerts\x18\x01 \x03(\x05\x12\x14\n\x0cgroup_alerts\x18\x02 \x03(\x05\x12\x15\n\rsevere_alerts\x18\x03 \x01(\x05\x12\x16\n\x0ewarning_alerts\x18\x04 \x01(\x05\x12\x14\n\x0ctotal_alerts\x18\x05 \x01(\x05\x12 \n\x18\x61lerts_weighted_by_level\x18\x06 \x01(\x02\x12\n\n\x02ip\x18\x07 \x01(\t\x12\n\n\x02ts\x18\x08 \x01(\x02\"\xb5\x01\n\x18SnortIdsAlertCountersDTO\x12\x17\n\x0fpriority_alerts\x18\x01 \x03(\x05\x12\x14\n\x0c\x63lass_alerts\x18\x02 \x03(\x05\x12\x15\n\rsevere_alerts\x18\x03 \x01(\x05\x12\x16\n\x0ewarning_alerts\x18\x04 \x01(\x05\x12#\n\x1b\x61lerts_weighted_by_priority\x18\x05 \x01(\x02\x12\n\n\x02ip\x18\x06 \x01(\t\x12\n\n\x02ts\x18\x07 \x01(\x02\"U\n\x1bSnortIdsIpAlertCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x1b.SnortIdsIpAlertCountersDTO\"Q\n\x19SnortIdsAlertCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x19.SnortIdsAlertCountersDTO\"O\n\x18SnortIdsRuleCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x18.SnortIdsRuleCountersDTO\"\xc9\x01\n\x1aSnortIdsIpAlertCountersDTO\x12\x17\n\x0fpriority_alerts\x18\x01 \x03(\x05\x12\x14\n\x0c\x63lass_alerts\x18\x02 \x03(\x05\x12\x15\n\rsevere_alerts\x18\x03 \x01(\x05\x12\x16\n\x0ewarning_alerts\x18\x04 \x01(\x05\x12#\n\x1b\x61lerts_weighted_by_priority\x18\x05 \x01(\x02\x12\n\n\x02ip\x18\x06 \x01(\t\x12\n\n\x02ts\x18\x07 \x01(\x02\x12\x10\n\x08\x61lert_ip\x18\x08 \x01(\t\"^\n\x17SnortIdsRuleCountersDTO\x12\x10\n\x08rule_ids\x18\x01 \x03(\t\x12\x19\n\x11rule_alert_counts\x18\x02 \x03(\x05\x12\n\n\x02ip\x18\x03 \x01(\t\x12\n\n\x02ts\x18\x04 \x01(\x02\"\xf4\x01\n\x1a\x45mulationAttackerActionDTO\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63mds\x18\x03 \x03(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\r\n\x05\x64\x65scr\x18\x05 \x01(\t\x12\x0b\n\x03ips\x18\x06 \x03(\t\x12\r\n\x05index\x18\x07 \x01(\x05\x12\x16\n\x0e\x61\x63tion_outcome\x18\x08 \x01(\x05\x12\x10\n\x08\x61lt_cmds\x18\t \x03(\t\x12\x16\n\x0e\x65xecution_time\x18\n \x01(\x02\x12\n\n\x02ts\x18\x0b \x01(\x02\x12\x15\n\rvulnerability\x18\x0c \x01(\t\x12\x10\n\x08\x62\x61\x63kdoor\x18\r \x01(\x08\"\xcb\x01\n\x1a\x45mulationDefenderActionDTO\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63mds\x18\x03 \x03(\t\x12\x0c\n\x04type\x18\x04 \x01(\x05\x12\r\n\x05\x64\x65scr\x18\x05 \x01(\t\x12\x0b\n\x03ips\x18\x06 \x03(\t\x12\r\n\x05index\x18\x07 \x01(\x05\x12\x16\n\x0e\x61\x63tion_outcome\x18\x08 \x01(\x05\x12\x10\n\x08\x61lt_cmds\x18\t \x03(\t\x12\x16\n\x0e\x65xecution_time\x18\n \x01(\x02\x12\n\n\x02ts\x18\x0b \x01(\x02\"\xce\x01\n\x12HostMetricsDataDTO\x12\x1b\n\x13num_logged_in_users\x18\x01 \x01(\x05\x12!\n\x19num_failed_login_attempts\x18\x02 \x01(\x05\x12\x1c\n\x14num_open_connections\x18\x03 \x01(\x05\x12\x18\n\x10num_login_events\x18\x04 \x01(\x05\x12\x15\n\rnum_processes\x18\x05 \x01(\x05\x12\x11\n\tnum_users\x18\x06 \x01(\x05\x12\n\n\x02ip\x18\x07 \x01(\t\x12\n\n\x02ts\x18\x08 \x01(\x02\"\xf8\x01\n\x0e\x44ockerStatsDTO\x12\x0c\n\x04pids\x18\x01 \x01(\x02\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x63pu_percent\x18\x03 \x01(\x02\x12\x13\n\x0bmem_current\x18\x04 \x01(\x02\x12\x11\n\tmem_total\x18\x05 \x01(\x02\x12\x13\n\x0bmem_percent\x18\x06 \x01(\x02\x12\x10\n\x08\x62lk_read\x18\x07 \x01(\x02\x12\x11\n\tblk_write\x18\x08 \x01(\x02\x12\x0e\n\x06net_rx\x18\t \x01(\x02\x12\x0e\n\x06net_tx\x18\n \x01(\x02\x12\x16\n\x0e\x63ontainer_name\x18\x0b \x01(\t\x12\n\n\x02ip\x18\x0c \x01(\t\x12\n\n\x02ts\x18\r \x01(\x02\"m\n\x1a\x43lientPopulationMetricsDTO\x12\n\n\x02ip\x18\x01 \x01(\t\x12\n\n\x02ts\x18\x02 \x01(\x02\x12\x13\n\x0bnum_clients\x18\x03 \x01(\x05\x12\x0c\n\x04rate\x18\x04 \x01(\x02\x12\x14\n\x0cservice_time\x18\x05 \x01(\x02\"\x1a\n\x18GetClusterManagerLogsMsg\"S\n\x13GetContainerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"B\n\x17GetClientManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16GetKafkaManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\":\n\x0fGetKafkaLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"R\n\x12GetSnortIdsLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Y\n\x19GetSnortIdsManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Y\n\x19GetOSSECIdsManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"R\n\x12GetOSSECIdsLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"U\n\x15GetHostManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"X\n\x18GetTrafficManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"?\n\x14GetElkManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"8\n\rGetElkLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14GetRyuManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17GetRyuControllerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17StopRyuMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18StartRyuMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"D\n\x19StopHostMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"X\n\x18StopHostMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"@\n\x15RemoveKibanaTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15\x43reateKibanaTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\x16\n\x14ListKibanaTunnelsMsg\"5\n\x10KibanaTunnelsDTO\x12!\n\x07tunnels\x18\x01 \x03(\x0b\x32\x10.KibanaTunnelDTO\"T\n\x0fKibanaTunnelDTO\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\temulation\x18\x03 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x04 \x01(\x05\"=\n\x12RemoveRyuTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12\x43reateRyuTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\x13\n\x11ListRyuTunnelsMsg\"/\n\rRyuTunnelsDTO\x12\x1e\n\x07tunnels\x18\x01 \x03(\x0b\x32\r.RyuTunnelDTO\"Q\n\x0cRyuTunnelDTO\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\temulation\x18\x03 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x04 \x01(\x05\"P\n SnortIdsMonitorThreadStatusesDTO\x12,\n\x10snortIDSStatuses\x18\x01 \x03(\x0b\x32\x12.SnortIdsStatusDTO\"E\n\x1aGetSnortIdsManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"N\n#GetSnortIdsMonitorThreadStatusesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"H\n\x1dStopSnortIdsMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"V\n\x16StopSnortIdsManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"W\n\x17StartSnortIdsManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"B\n\x17StopSnortIdsManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18StartSnortIdsManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"M\n\rStartSnortMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"]\n\x1dStartSnortIdsMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"I\n\x1eStartSnortIdsMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"L\n\x0cStopSnortMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"\\\n\x1cStopSnortIdsMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"<\n\x11StopSnortIdsesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"J\n\x1fStopSnortIdsesMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15GetRyuManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18StopRyuMonitorServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"D\n\x19StartRyuMonitorServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11StopRyuServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StartRyuServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16GetRyuServiceStatusMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11StopRyuManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StartRyuManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"E\n\x1aGetOSSECIDSManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"P\n OSSECIdsMonitorThreadStatusesDTO\x12,\n\x10ossecIDSStatuses\x18\x01 \x03(\x0b\x32\x12.OSSECIdsStatusDTO\"N\n#GetOSSECIDSMonitorThreadStatusesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"H\n\x1dStopOSSECIDSMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\\\n\x1cStopOSSECIDSMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"]\n\x1dStartOSSECIDSMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"S\n\x13StopOSSECIDSManager\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"T\n\x14StartOSSECIDSManager\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"?\n\x14StopOSSECIDSManagers\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15StartOSSECIDSManagers\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"P\n\x10StartOSSECIDSMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"O\n\x0fStopOSSECIDSMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"=\n\x12StartOSSECIDSesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11StopOSSECIDSesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17GetKafkaManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13StartKafkaServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StopKafkaServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18GetKafkaManagerStatusMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14\x43reateKafkaTopicsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13StopKafkaManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14StartKafkaManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16GetHostManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"K\n GetHostMonitorThreadsStatusesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"V\n\x16\x41pplyFileBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"X\n\x18\x41pplyPacketBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"X\n\x18\x41pplyMetricBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"W\n\x17\x41pplyHeartBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"O\n\x0fStopFileBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Q\n\x11StopPacketBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Q\n\x11StopMetricBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"P\n\x10StopHeartBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"f\n\x10StartFileBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"h\n\x12StartPacketBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"h\n\x12StartMetricBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"g\n\x11StartHeartBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"Y\n\x19StartHostMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"<\n\x11StopHeartbeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StopPacketbeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\";\n\x10StopFilebeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StopMetricbeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"E\n\x1aStartHostMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"R\n\x12StopHostManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"S\n\x13StartHostManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\">\n\x13StopHostManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\xdc\x06\n\x10\x45xecutionInfoDTO\x12\x15\n\remulationName\x18\x01 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x02 \x01(\x05\x12\x36\n\x14snortIdsManagersInfo\x18\x03 \x01(\x0b\x32\x18.SnortIdsManagersInfoDTO\x12\x36\n\x14ossecIdsManagersInfo\x18\x04 \x01(\x0b\x32\x18.OSSECIdsManagersInfoDTO\x12\x30\n\x11kafkaManagersInfo\x18\x05 \x01(\x0b\x32\x15.KafkaManagersInfoDTO\x12.\n\x10hostManagersInfo\x18\x06 \x01(\x0b\x32\x14.HostManagersInfoDTO\x12\x32\n\x12\x63lientManagersInfo\x18\x07 \x01(\x0b\x32\x16.ClientManagersInfoDTO\x12<\n\x17\x64ockerStatsManagersInfo\x18\x08 \x01(\x0b\x32\x1b.DockerStatsManagersInfoDTO\x12\x30\n\x11runningContainers\x18\t \x01(\x0b\x32\x15.RunningContainersDTO\x12\x30\n\x11stoppedContainers\x18\n \x01(\x0b\x32\x15.StoppedContainersDTO\x12\x37\n\x16trafficManagersInfoDTO\x18\x0b \x01(\x0b\x32\x17.TrafficManagersInfoDTO\x12*\n\x0e\x61\x63tiveNetworks\x18\x0c \x01(\x0b\x32\x12.DockerNetworksDTO\x12/\n\x12\x65lkManagersInfoDTO\x18\r \x01(\x0b\x32\x13.ElkManagersInfoDTO\x12/\n\x12ryuManagersInfoDTO\x18\x0e \x01(\x0b\x32\x13.RyuManagersInfoDTO\x12;\n\x18\x66iveGCoreManagersInfoDTO\x18\x0f \x01(\x0b\x32\x19.FiveGCoreManagersInfoDTO\x12\x37\n\x16\x66iveGCUManagersInfoDTO\x18\x10 \x01(\x0b\x32\x17.FiveGCUManagersInfoDTO\x12\x37\n\x16\x66iveGDUManagersInfoDTO\x18\x11 \x01(\x0b\x32\x17.FiveGDUManagersInfoDTO\"\xe5\x01\n\x12RyuManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1a\n\x12ryuManagersRunning\x18\x05 \x03(\x08\x12\x31\n\x13ryuManagersStatuses\x18\x06 \x03(\x0b\x32\x14.RyuManagerStatusDTO\x12\x1e\n\x16localControllerWebPort\x18\x07 \x01(\x05\x12\x18\n\x10physicalServerIp\x18\x08 \x01(\t\"\xb4\x01\n\x13RyuManagerStatusDTO\x12\x13\n\x0bryu_running\x18\x01 \x01(\x08\x12\x17\n\x0fmonitor_running\x18\x02 \x01(\x08\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x10\n\x08web_port\x18\x04 \x01(\x05\x12\x12\n\ncontroller\x18\x05 \x01(\t\x12\x10\n\x08kafka_ip\x18\x06 \x01(\t\x12\x12\n\nkafka_port\x18\x07 \x01(\x05\x12\x15\n\rtime_step_len\x18\x08 \x01(\x05\"\xaf\x01\n\x13HostManagersInfoDTO\x12\x0b\n\x03ips\x18\x15 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1b\n\x13hostManagersRunning\x18\x05 \x03(\x08\x12\x33\n\x14hostManagersStatuses\x18\x06 \x03(\x0b\x32\x15.HostManagerStatusDTO\"L\n\x16HostManagerStatusesDTO\x12\x32\n\x13hostManagerStatuses\x18\x01 \x03(\x0b\x32\x15.HostManagerStatusDTO\"\xa8\x01\n\x14HostManagerStatusDTO\x12\x17\n\x0fmonitor_running\x18\x01 \x01(\x08\x12\x18\n\x10\x66ilebeat_running\x18\x02 \x01(\x08\x12\x1a\n\x12packetbeat_running\x18\x03 \x01(\x08\x12\x1a\n\x12metricbeat_running\x18\x04 \x01(\x08\x12\x19\n\x11heartbeat_running\x18\x05 \x01(\x08\x12\n\n\x02ip\x18\x06 \x01(\t\"\xac\x01\n\x14KafkaManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1c\n\x14kafkaManagersRunning\x18\x05 \x03(\x08\x12.\n\x15kafkaManagersStatuses\x18\x06 \x03(\x0b\x32\x0f.KafkaStatusDTO\"1\n\x0eKafkaStatusDTO\x12\x0f\n\x07running\x18\x01 \x01(\x08\x12\x0e\n\x06topics\x18\x02 \x03(\t\"\xb8\x01\n\x17OSSECIdsManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1f\n\x17ossecIdsManagersRunning\x18\x05 \x03(\x08\x12\x34\n\x18ossecIdsManagersStatuses\x18\x06 \x03(\x0b\x32\x12.OSSECIdsStatusDTO\"G\n\x11OSSECIdsStatusDTO\x12\x17\n\x0fmonitor_running\x18\x01 \x01(\x08\x12\x19\n\x11ossec_ids_running\x18\x02 \x01(\x08\"\xb8\x01\n\x17SnortIdsManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1f\n\x17snortIdsManagersRunning\x18\x05 \x03(\x08\x12\x34\n\x18snortIdsManagersStatuses\x18\x06 \x03(\x0b\x32\x12.SnortIdsStatusDTO\"G\n\x11SnortIdsStatusDTO\x12\x17\n\x0fmonitor_running\x18\x01 \x01(\x08\x12\x19\n\x11snort_ids_running\x18\x02 \x01(\x08\">\n\x13GetExecutionInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"G\n\x1cStopContainersOfExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"y\n\x0fRunContainerMsg\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06memory\x18\x03 \x01(\x05\x12\x10\n\x08num_cpus\x18\x04 \x01(\x05\x12\x16\n\x0e\x63reate_network\x18\x05 \x01(\x08\x12\x0f\n\x07version\x18\x06 \x01(\t\"H\n\x1dStartContainersOfExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15GetElkManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\xd7\x01\n\x12\x45lkManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1a\n\x12\x65lkManagersRunning\x18\x05 \x03(\x08\x12*\n\x13\x65lkManagersStatuses\x18\x06 \x03(\x0b\x32\r.ElkStatusDTO\x12\x17\n\x0flocalKibanaPort\x18\x07 \x01(\x05\x12\x18\n\x10physicalServerIp\x18\x08 \x01(\t\"A\n\x16StopLogstashServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17StartLogstashServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14StopKibanaServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15StartKibanaServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15StopElasticServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16StartElasticServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\":\n\x0fStopElkStackMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"V\n\x0c\x45lkStatusDTO\x12\x16\n\x0e\x65lasticRunning\x18\x01 \x01(\x08\x12\x15\n\rkibanaRunning\x18\x02 \x01(\x08\x12\x17\n\x0flogstashRunning\x18\x03 \x01(\x08\"?\n\x14GetElkStackStatusMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11StopElkManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StartElkManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"H\n\x1dGetDockerStatsManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\xcb\x01\n\x1a\x44ockerStatsManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\"\n\x1a\x64ockerStatsManagersRunning\x18\x05 \x03(\x08\x12\x41\n\x1b\x64ockerStatsManagersStatuses\x18\x06 \x03(\x0b\x32\x1c.DockerStatsMonitorStatusDTO\"\x1c\n\x1aRemoveAllDockerNetworksMsg\"+\n\x17RemoveDockerNetworksMsg\x12\x10\n\x08networks\x18\x01 \x03(\t\"e\n\x1b\x44ockerStatsMonitorStatusDTO\x12\x14\n\x0cnum_monitors\x18\x01 \x01(\x05\x12\x12\n\nemulations\x18\x02 \x03(\t\x12\x1c\n\x14\x65mulation_executions\x18\x03 \x03(\x05\".\n\x1eGetDockerStatsManagerStatusMsg\x12\x0c\n\x04port\x18\x01 \x01(\x05\"J\n\x1fStopDockerStatsManagerThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"E\n\x1a\x43reateEmulationNetworksMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\x1d\n\x1bListAllStoppedContainersMsg\"F\n\x14StoppedContainersDTO\x12.\n\x11stoppedContainers\x18\x01 \x03(\x0b\x32\x13.DockerContainerDTO\"\x1d\n\x1bListAllRunningEmulationsMsg\"1\n\x14RunningEmulationsDTO\x12\x19\n\x11runningEmulations\x18\x01 \x03(\t\"\x1d\n\x1bListAllRunningContainersMsg\"F\n\x14RunningContainersDTO\x12.\n\x11runningContainers\x18\x01 \x03(\x0b\x32\x13.DockerContainerDTO\"=\n\x12\x44ockerContainerDTO\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\n\n\x02ip\x18\x03 \x01(\t\"!\n\x11StartContainerMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1e\n\x1cStartAllStoppedContainersMsg\"\x1a\n\x18ListAllDockerNetworksMsg\":\n\x11\x44ockerNetworksDTO\x12\x10\n\x08networks\x18\x01 \x03(\t\x12\x13\n\x0bnetwork_ids\x18\x02 \x03(\x05\"8\n\x12\x43ontainerImagesDTO\x12\"\n\x06images\x18\x01 \x03(\x0b\x32\x12.ContainerImageDTO\"f\n\x11\x43ontainerImageDTO\x12\x10\n\x08repoTags\x18\x01 \x01(\t\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\n\n\x02os\x18\x03 \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x03\"\x1b\n\x19ListAllContainerImagesMsg\"\'\n\x17RemoveContainerImageMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1d\n\x1bRemoveAllContainerImagesMsg\"\x1f\n\x1dRemoveAllStoppedContainersMsg\"\"\n\x12RemoveContainerMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x10StopContainerMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1d\n\x1bStopAllRunningContainersMsg\"D\n\x19GetTrafficManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\xb9\x01\n\x16TrafficManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1e\n\x16trafficManagersRunning\x18\x05 \x03(\x08\x12\x37\n\x17trafficManagersStatuses\x18\x06 \x03(\x0b\x32\x16.TrafficManagerInfoDTO\"8\n\x15TrafficManagerInfoDTO\x12\x0f\n\x07running\x18\x01 \x01(\x08\x12\x0e\n\x06script\x18\x02 \x01(\t\"\xb1\x01\n\x15\x43lientManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1d\n\x15\x63lientManagersRunning\x18\x05 \x03(\x08\x12\x31\n\x16\x63lientManagersStatuses\x18\x06 \x03(\x0b\x32\x11.GetNumClientsDTO\"C\n\x18GetClientManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"X\n\x18StartTrafficGeneratorMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"W\n\x17StopTrafficGeneratorMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"C\n\x18StopTrafficGeneratorsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\xae\x01\n\x10GetNumClientsDTO\x12\x13\n\x0bnum_clients\x18\x01 \x01(\x05\x12\x1d\n\x15\x63lient_process_active\x18\x02 \x01(\x08\x12\x17\n\x0fproducer_active\x18\x03 \x01(\x08\x12%\n\x1d\x63lients_time_step_len_seconds\x18\x04 \x01(\x05\x12&\n\x1eproducer_time_step_len_seconds\x18\x05 \x01(\x05\"A\n\x16GetNumActiveClientsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17StopClientPopulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14StopClientManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15StartClientManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16StopTrafficManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"U\n\x15StopTrafficManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"V\n\x16StartTrafficManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"\x17\n\x15\x43leanAllExecutionsMsg\"\x16\n\x14StopAllExecutionsMsg\";\n\x10StopExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11\x43leanExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"4\n\x1fStopAllExecutionsOfEmulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\"5\n CleanAllExecutionsOfEmulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\"\x14\n\x12GetCsleLogFilesMsg\"\x1d\n\rGetLogFileMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"H\n\x1dStartContainersInExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"S\n(AttachContainersToNetworksInExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13InstallLibrariesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13\x41pplyKafkaConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15StartSdnControllerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"E\n\x1a\x41pplyResouceConstraintsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14\x43reateOvsSwitchesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\";\n\x10PingExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\":\n\x0f\x43onfigureOvsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"G\n\x1cStartSdnControllerMonitorMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"9\n\x0e\x43reateUsersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"9\n\x0e\x43reateVulnsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"9\n\x0e\x43reateFlagsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"<\n\x11\x43reateTopologyMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17StartTrafficManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"D\n\x19StartTrafficGeneratorsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18StartClientPopulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"F\n\x1bStartKafkaClientProducerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"E\n\x1aStopKafkaClientProducerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StartSnortIdsesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"K\n StartSnortIdsesMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"=\n\x12StartOSSECIdsesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"K\n StartOSSECIdsesMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\";\n\x10StartElkStackMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14StartHostManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"B\n\x17\x41pplyFileBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"D\n\x19\x41pplyPacketBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"D\n\x19\x41pplyMetricBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18\x41pplyHeartBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"R\n\x11StartFileBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"T\n\x13StartPacketBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"T\n\x13StartMetricBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"S\n\x12StartHeartBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"\x1e\n\x1cGetDockerStatsManagerLogsMsg\"\x16\n\x14GetPrometheusLogsMsg\"\x18\n\x16GetNodeExporterLogsMsg\"\x14\n\x12GetCAdvisorLogsMsg\"\x13\n\x11GetPgAdminLogsMsg\"\x13\n\x11GetGrafanaLogsMsg\"\x11\n\x0fGetNginxLogsMsg\"\x12\n\x10GetDockerLogsMsg\"\x16\n\x14GetPostgreSQLLogsMsg\"\x11\n\x0fGetFlaskLogsMsg\"\x17\n\x07LogsDTO\x12\x0c\n\x04logs\x18\x01 \x03(\t\"&\n\x13OperationOutcomeDTO\x12\x0f\n\x07outcome\x18\x01 \x01(\x08\"\x12\n\x10GetNodeStatusMsg\"\xb3\x02\n\rNodeStatusDTO\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0e\n\x06leader\x18\x02 \x01(\x08\x12\x17\n\x0f\x63\x41\x64visorRunning\x18\x03 \x01(\x08\x12\x19\n\x11prometheusRunning\x18\x04 \x01(\x08\x12\x16\n\x0egrafanaRunning\x18\x05 \x01(\x08\x12\x16\n\x0epgAdminRunning\x18\x06 \x01(\x08\x12\x14\n\x0cnginxRunning\x18\x07 \x01(\x08\x12\x14\n\x0c\x66laskRunning\x18\x08 \x01(\x08\x12!\n\x19\x64ockerStatsManagerRunning\x18\t \x01(\x08\x12\x1b\n\x13nodeExporterRunning\x18\n \x01(\x08\x12\x19\n\x11postgreSQLRunning\x18\x0b \x01(\x08\x12\x1b\n\x13\x64ockerEngineRunning\x18\x0c \x01(\x08\"#\n\x10ServiceStatusDTO\x12\x0f\n\x07running\x18\x01 \x01(\x08\"\x14\n\x12StartPostgreSQLMsg\"\x12\n\x10StartCAdvisorMsg\"\x16\n\x14StartNodeExporterMsg\"\x11\n\x0fStartGrafanaMsg\"\x14\n\x12StartPrometheusMsg\"\x11\n\x0fStartPgAdminMsg\"\x0f\n\rStartNginxMsg\"\x0f\n\rStartFlaskMsg\"\x1c\n\x1aStartDockerStatsManagerMsg\"K\n StartDockerStatsManagerThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\x16\n\x14StartDockerEngineMsg\"\x13\n\x11StopPostgreSQLMsg\"\x11\n\x0fStopCAdvisorMsg\"\x15\n\x13StopNodeExporterMsg\"\x10\n\x0eStopGrafanaMsg\"\x13\n\x11StopPrometheusMsg\"\x10\n\x0eStopPgAdminMsg\"\x0e\n\x0cStopNginxMsg\"\x0e\n\x0cStopFlaskMsg\"\x1b\n\x19StopDockerStatsManagerMsg\"\x15\n\x13StopDockerEngineMsg\"A\n\x16Start5GCoreManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"@\n\x15Stop5GCoreManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"U\n\x15Start5GCoreManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"T\n\x14Stop5GCoreManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"M\n\rStop5GCoreMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"9\n\x0eStop5GCoresMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"N\n\x0eStart5GCoreMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\":\n\x0fStart5GCoresMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"M\n\rInit5GCoreMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"9\n\x0eInit5GCoresMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14Start5GCUManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13Stop5GCUManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"S\n\x13Start5GCUManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"R\n\x12Stop5GCUManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"K\n\x0bStop5GCUMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"7\n\x0cStop5GCUsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"L\n\x0cStart5GCUMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"8\n\rStart5GCUsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"?\n\x14Start5GDUManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\">\n\x13Stop5GDUManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"S\n\x13Start5GDUManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"R\n\x12Stop5GDUManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"K\n\x0bStop5GDUMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"7\n\x0cStop5GDUsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"L\n\x0cStart5GDUMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"8\n\rStart5GDUsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"K\n\x0bStop5GUEMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"7\n\x0cStop5GUEsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"L\n\x0cStart5GUEMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"8\n\rStart5GUEsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"K\n\x0bInit5GUEMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"7\n\x0cInit5GUEsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"C\n\x18Get5GCoreManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16Get5GCUManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"A\n\x16Get5GDUManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\"\xb7\x03\n\x10\x46iveGCoreInfoDTO\x12\x15\n\rmongo_running\x18\x01 \x01(\x08\x12\x13\n\x0bmme_running\x18\x02 \x01(\x08\x12\x14\n\x0csgwc_running\x18\x03 \x01(\x08\x12\x13\n\x0bsmf_running\x18\x04 \x01(\x08\x12\x13\n\x0b\x61mf_running\x18\x05 \x01(\x08\x12\x14\n\x0csgwu_running\x18\x06 \x01(\x08\x12\x13\n\x0bupf_running\x18\x07 \x01(\x08\x12\x13\n\x0bhss_running\x18\x08 \x01(\x08\x12\x14\n\x0cpcrf_running\x18\t \x01(\x08\x12\x13\n\x0bnrf_running\x18\n \x01(\x08\x12\x13\n\x0bscp_running\x18\x0b \x01(\x08\x12\x14\n\x0csepp_running\x18\x0c \x01(\x08\x12\x14\n\x0c\x61usf_running\x18\r \x01(\x08\x12\x13\n\x0budm_running\x18\x0e \x01(\x08\x12\x13\n\x0bpcf_running\x18\x0f \x01(\x08\x12\x14\n\x0cnssf_running\x18\x10 \x01(\x08\x12\x13\n\x0b\x62sf_running\x18\x11 \x01(\x08\x12\x13\n\x0budr_running\x18\x12 \x01(\x08\x12\x15\n\rwebui_running\x18\x13 \x01(\x08\x12\n\n\x02ip\x18\x14 \x01(\t\"0\n\x0e\x46iveGCUInfoDTO\x12\x12\n\ncu_running\x18\x01 \x01(\x08\x12\n\n\x02ip\x18\x02 \x01(\t\"D\n\x0e\x46iveGDUInfoDTO\x12\x12\n\ndu_running\x18\x01 \x01(\x08\x12\x12\n\nue_running\x18\x02 \x01(\x08\x12\n\n\x02ip\x18\x03 \x01(\t\"\xba\x01\n\x18\x46iveGCoreManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12 \n\x18\x66iveGCoreManagersRunning\x18\x05 \x03(\x08\x12\x34\n\x19\x66iveGCoreManagersStatuses\x18\x06 \x03(\x0b\x32\x11.FiveGCoreInfoDTO\"\xb2\x01\n\x16\x46iveGCUManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1e\n\x16\x66iveGCUManagersRunning\x18\x05 \x03(\x08\x12\x30\n\x17\x66iveGCUManagersStatuses\x18\x06 \x03(\x0b\x32\x0f.FiveGCUInfoDTO\"\xb2\x01\n\x16\x46iveGDUManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x05\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x05\x12\x1e\n\x16\x66iveGDUManagersRunning\x18\x05 \x03(\x08\x12\x30\n\x17\x66iveGDUManagersStatuses\x18\x06 \x03(\x0b\x32\x0f.FiveGDUInfoDTO\"W\n\x17Get5GCoreManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"U\n\x15Get5GCUManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"U\n\x15Get5GDUManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"P\n\x10Get5GCoreLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"N\n\x0eGet5GCULogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"N\n\x0eGet5GDULogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"N\n\x0eGet5GUELogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x05\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t2\xd7\x85\x01\n\x0e\x43lusterManager\x12\x34\n\rgetNodeStatus\x12\x11.GetNodeStatusMsg\x1a\x0e.NodeStatusDTO\"\x00\x12;\n\x0fstartPostgreSQL\x12\x13.StartPostgreSQLMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x37\n\rstartCAdvisor\x12\x11.StartCAdvisorMsg\x1a\x11.ServiceStatusDTO\"\x00\x12?\n\x11startNodeExporter\x12\x15.StartNodeExporterMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x35\n\x0cstartGrafana\x12\x10.StartGrafanaMsg\x1a\x11.ServiceStatusDTO\"\x00\x12;\n\x0fstartPrometheus\x12\x13.StartPrometheusMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x35\n\x0cstartPgAdmin\x12\x10.StartPgAdminMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x31\n\nstartNginx\x12\x0e.StartNginxMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x31\n\nstartFlask\x12\x0e.StartFlaskMsg\x1a\x11.ServiceStatusDTO\"\x00\x12K\n\x17startDockerStatsManager\x12\x1b.StartDockerStatsManagerMsg\x1a\x11.ServiceStatusDTO\"\x00\x12W\n\x1dstartDockerStatsManagerThread\x12!.StartDockerStatsManagerThreadMsg\x1a\x11.ServiceStatusDTO\"\x00\x12?\n\x11startDockerEngine\x12\x15.StartDockerEngineMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x39\n\x0estopPostgreSQL\x12\x12.StopPostgreSQLMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x35\n\x0cstopCAdvisor\x12\x10.StopCAdvisorMsg\x1a\x11.ServiceStatusDTO\"\x00\x12=\n\x10stopNodeExporter\x12\x14.StopNodeExporterMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x33\n\x0bstopGrafana\x12\x0f.StopGrafanaMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x39\n\x0estopPrometheus\x12\x12.StopPrometheusMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x33\n\x0bstopPgAdmin\x12\x0f.StopPgAdminMsg\x1a\x11.ServiceStatusDTO\"\x00\x12/\n\tstopNginx\x12\r.StopNginxMsg\x1a\x11.ServiceStatusDTO\"\x00\x12/\n\tstopFlask\x12\r.StopFlaskMsg\x1a\x11.ServiceStatusDTO\"\x00\x12I\n\x16stopDockerStatsManager\x12\x1a.StopDockerStatsManagerMsg\x1a\x11.ServiceStatusDTO\"\x00\x12=\n\x10stopDockerEngine\x12\x14.StopDockerEngineMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x32\n\x0fgetCsleLogFiles\x12\x13.GetCsleLogFilesMsg\x1a\x08.LogsDTO\"\x00\x12\x46\n\x19getDockerStatsManagerLogs\x12\x1d.GetDockerStatsManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x36\n\x11getPrometheusLogs\x12\x15.GetPrometheusLogsMsg\x1a\x08.LogsDTO\"\x00\x12:\n\x13getNodeExporterLogs\x12\x17.GetNodeExporterLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x32\n\x0fgetCadvisorLogs\x12\x13.GetCAdvisorLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x30\n\x0egetPgAdminLogs\x12\x12.GetPgAdminLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x30\n\x0egetGrafanaLogs\x12\x12.GetGrafanaLogsMsg\x1a\x08.LogsDTO\"\x00\x12,\n\x0cgetNginxLogs\x12\x10.GetNginxLogsMsg\x1a\x08.LogsDTO\"\x00\x12.\n\rgetDockerLogs\x12\x11.GetDockerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x37\n\x12getPostrgreSQLLogs\x12\x15.GetPostgreSQLLogsMsg\x1a\x08.LogsDTO\"\x00\x12,\n\x0cgetFlaskLogs\x12\x10.GetFlaskLogsMsg\x1a\x08.LogsDTO\"\x00\x12(\n\ngetLogFile\x12\x0e.GetLogFileMsg\x1a\x08.LogsDTO\"\x00\x12T\n\x1astartContainersInExecution\x12\x1e.StartContainersInExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12j\n%attachContainersInExecutionToNetworks\x12).AttachContainersToNetworksInExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10installLibraries\x12\x14.InstallLibrariesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10\x61pplyKafkaConfig\x12\x14.ApplyKafkaConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12startSdnController\x12\x16.StartSdnControllerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12O\n\x18\x61pplyResourceConstraints\x12\x1b.ApplyResouceConstraintsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11\x63reateOvsSwitches\x12\x15.CreateOvsSwitchesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rpingExecution\x12\x11.PingExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0c\x63onfigureOvs\x12\x10.ConfigureOvsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19startSdnControllerMonitor\x12\x1d.StartSdnControllerMonitorMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0b\x63reateUsers\x12\x0f.CreateUsersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x15\x63reateVulnerabilities\x12\x0f.CreateVulnsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0b\x63reateFlags\x12\x0f.CreateFlagsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0e\x63reateTopology\x12\x12.CreateTopologyMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14startTrafficManagers\x12\x18.StartTrafficManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16startTrafficGenerators\x12\x1a.StartTrafficGeneratorsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15startClientPopulation\x12\x19.StartClientPopulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12P\n\x18startKafkaClientProducer\x12\x1c.StartKafkaClientProducerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17stopKafkaClientProducer\x12\x1b.StopKafkaClientProducerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartSnortIdses\x12\x13.StartSnortIdsesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Z\n\x1dstartSnortIdsesMonitorThreads\x12!.StartSnortIdsesMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartOssecIdses\x12\x13.StartOSSECIdsesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Z\n\x1dstartOssecIdsesMonitorThreads\x12!.StartOSSECIdsesMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstartElkStack\x12\x11.StartElkStackMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11startHostManagers\x12\x15.StartHostManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14\x61pplyFileBeatsConfig\x12\x18.ApplyFileBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16\x61pplyPacketBeatsConfig\x12\x1a.ApplyPacketBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16\x61pplyMetricBeatsConfig\x12\x1a.ApplyMetricBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15\x61pplyHeartBeatsConfig\x12\x19.ApplyHeartBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estartFilebeats\x12\x12.StartFileBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startPacketbeats\x12\x14.StartPacketBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startMetricbeats\x12\x14.StartMetricBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartHeartbeats\x12\x13.StartHeartBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12X\n\x1cstopAllExecutionsOfEmulation\x12 .StopAllExecutionsOfEmulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopExecution\x12\x11.StopExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11stopAllExecutions\x12\x15.StopAllExecutionsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12\x63leanAllExecutions\x12\x16.CleanAllExecutionsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Z\n\x1d\x63leanAllExecutionsOfEmulation\x12!.CleanAllExecutionsOfEmulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0e\x63leanExecution\x12\x12.CleanExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x46\n\x13startTrafficManager\x12\x17.StartTrafficManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x45\n\x12stopTrafficManager\x12\x17.StartTrafficManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12G\n\x13stopTrafficManagers\x12\x18.StartTrafficManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12startClientManager\x12\x16.StartClientManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14stopClientPopulation\x12\x18.StopClientPopulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11stopClientManager\x12\x15.StopClientManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x13getNumActiveClients\x12\x17.GetNumActiveClientsMsg\x1a\x11.GetNumClientsDTO\"\x00\x12J\n\x15startTrafficGenerator\x12\x19.StartTrafficGeneratorMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15stopTrafficGenerators\x12\x19.StopTrafficGeneratorsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14stopTrafficGenerator\x12\x18.StopTrafficGeneratorMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x15getClientManagersInfo\x12\x19.GetClientManagersInfoMsg\x1a\x16.ClientManagersInfoDTO\"\x00\x12O\n\x16getTrafficManagersInfo\x12\x1a.GetTrafficManagersInfoMsg\x1a\x17.TrafficManagersInfoDTO\"\x00\x12P\n\x18stopAllRunningContainers\x12\x1c.StopAllRunningContainersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopContainer\x12\x11.StopContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1aremoveAllStoppedContainers\x12\x1e.RemoveAllStoppedContainersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fremoveContainer\x12\x13.RemoveContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12P\n\x18removeAllContainerImages\x12\x1c.RemoveAllContainerImagesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14removeContainerImage\x12\x18.RemoveContainerImageMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12K\n\x16listAllContainerImages\x12\x1a.ListAllContainerImagesMsg\x1a\x13.ContainerImagesDTO\"\x00\x12H\n\x15listAllDockerNetworks\x12\x19.ListAllDockerNetworksMsg\x1a\x12.DockerNetworksDTO\"\x00\x12R\n\x19startAllStoppedContainers\x12\x1d.StartAllStoppedContainersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estartContainer\x12\x12.StartContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Q\n\x18listAllRunningContainers\x12\x1c.ListAllRunningContainersMsg\x1a\x15.RunningContainersDTO\"\x00\x12Q\n\x18listAllRunningEmulations\x12\x1c.ListAllRunningEmulationsMsg\x1a\x15.RunningEmulationsDTO\"\x00\x12Q\n\x18listAllStoppedContainers\x12\x1c.ListAllStoppedContainersMsg\x1a\x15.StoppedContainersDTO\"\x00\x12N\n\x17\x63reateEmulationNetworks\x12\x1b.CreateEmulationNetworksMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12X\n\x1cstopDockerStatsManagerThread\x12 .StopDockerStatsManagerThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12^\n\x1bgetDockerStatsManagerStatus\x12\x1f.GetDockerStatsManagerStatusMsg\x1a\x1c.DockerStatsMonitorStatusDTO\"\x00\x12H\n\x14removeDockerNetworks\x12\x18.RemoveDockerNetworksMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17removeAllDockerNetworks\x12\x1b.RemoveAllDockerNetworksMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12[\n\x1agetDockerStatsManagersInfo\x12\x1e.GetDockerStatsManagersInfoMsg\x1a\x1b.DockerStatsManagersInfoDTO\"\x00\x12>\n\x0fstartElkManager\x12\x13.StartElkManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopElkManager\x12\x12.StopElkManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0cgetElkStatus\x12\x15.GetElkStackStatusMsg\x1a\r.ElkStatusDTO\"\x00\x12\x38\n\x0cstopElkStack\x12\x10.StopElkStackMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x0cstartElastic\x12\x17.StartElasticServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12=\n\x0bstopElastic\x12\x16.StopElasticServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12=\n\x0bstartKibana\x12\x16.StartKibanaServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12;\n\nstopKibana\x12\x15.StopKibanaServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x41\n\rstartLogstash\x12\x18.StartLogstashServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x0cstopLogstash\x12\x17.StopLogstashServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x12getElkManagersInfo\x12\x16.GetElkManagersInfoMsg\x1a\x13.ElkManagersInfoDTO\"\x00\x12T\n\x1astartContainersOfExecution\x12\x1e.StartContainersOfExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0crunContainer\x12\x10.RunContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19stopContainersOfExecution\x12\x1d.StopContainersOfExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startHostManager\x12\x14.StartHostManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10stopHostManagers\x12\x14.StopHostManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopHostManager\x12\x13.StopHostManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopFilebeats\x12\x11.StopFilebeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopPacketbeats\x12\x13.StopPacketbeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopMetricbeats\x12\x13.StopMetricbeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopHeartbeats\x12\x12.StopHeartbeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17startHostMonitorThreads\x12\x1b.StartHostMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16startHostMonitorThread\x12\x1a.StartHostMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstartFilebeat\x12\x11.StartFileBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartPacketbeat\x12\x13.StartPacketBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartMetricbeat\x12\x13.StartMetricBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estartHeartbeat\x12\x12.StartHeartBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0cstopFilebeat\x12\x10.StopFileBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopPacketbeat\x12\x12.StopPacketBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopMetricbeat\x12\x12.StopMetricBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopHeartbeat\x12\x11.StopHeartBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x46\n\x13\x61pplyFileBeatConfig\x12\x17.ApplyFileBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15\x61pplyPacketBeatConfig\x12\x19.ApplyPacketBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15\x61pplyMetricBeatConfig\x12\x19.ApplyMetricBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14\x61pplyHeartBeatConfig\x12\x18.ApplyHeartBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12]\n\x1dgetHostMonitorThreadsStatuses\x12!.GetHostMonitorThreadsStatusesMsg\x1a\x17.HostManagerStatusesDTO\"\x00\x12\x46\n\x13getHostManagersInfo\x12\x17.GetHostManagersInfoMsg\x1a\x14.HostManagersInfoDTO\"\x00\x12@\n\x10stopKafkaManager\x12\x14.StopKafkaManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11startKafkaManager\x12\x15.StartKafkaManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11\x63reateKafkaTopics\x12\x15.CreateKafkaTopicsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0egetKafkaStatus\x12\x19.GetKafkaManagerStatusMsg\x1a\x0f.KafkaStatusDTO\"\x00\x12>\n\x0fstopKafkaServer\x12\x13.StopKafkaServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x10startKafkaServer\x12\x13.StopKafkaServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12I\n\x14getKafkaManagersInfo\x12\x18.GetKafkaManagersInfoMsg\x1a\x15.KafkaManagersInfoDTO\"\x00\x12<\n\x0estopOSSECIDSes\x12\x12.StopOSSECIDSesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartOSSECIDSes\x12\x13.StartOSSECIDSesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0cstopOSSECIDS\x12\x10.StopOSSECIDSMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstartOSSECIDS\x12\x11.StartOSSECIDSMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12G\n\x15startOSSECIDSManagers\x12\x16.StartOSSECIDSManagers\x1a\x14.OperationOutcomeDTO\"\x00\x12\x45\n\x14stopOSSECIDSManagers\x12\x15.StopOSSECIDSManagers\x1a\x14.OperationOutcomeDTO\"\x00\x12\x45\n\x14startOSSECIDSManager\x12\x15.StartOSSECIDSManager\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x13stopOSSECIDSManager\x12\x14.StopOSSECIDSManager\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astartOSSECIDSMonitorThread\x12\x1e.StartOSSECIDSMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19stopOSSECIDSMonitorThread\x12\x1d.StopOSSECIDSMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astopOSSECIDSMonitorThreads\x12\x1e.StopOSSECIDSMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12m\n getOSSECIDSMonitorThreadStatuses\x12$.GetOSSECIDSMonitorThreadStatusesMsg\x1a!.OSSECIdsMonitorThreadStatusesDTO\"\x00\x12R\n\x17getOSSECIdsManagersInfo\x12\x1b.GetOSSECIDSManagersInfoMsg\x1a\x18.OSSECIdsManagersInfoDTO\"\x00\x12>\n\x0fstartRyuManager\x12\x13.StartRyuManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopRyuManager\x12\x12.StopRyuManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x0cgetRyuStatus\x12\x17.GetRyuServiceStatusMsg\x1a\x14.RyuManagerStatusDTO\"\x00\x12\x37\n\x08startRyu\x12\x13.StartRyuServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x35\n\x07stopRyu\x12\x12.StopRyuServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x12getRyuManagersInfo\x12\x16.GetRyuManagersInfoMsg\x1a\x13.RyuManagersInfoDTO\"\x00\x12<\n\x0estopSnortIdses\x12\x12.StopSnortIdsesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12X\n\x1cstopSnortIdsesMonitorThreads\x12 .StopSnortIdsesMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x35\n\x0cstopSnortIds\x12\r.StopSnortMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19stopSnortIdsMonitorThread\x12\x1d.StopSnortIdsMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x37\n\rstartSnortIds\x12\x0e.StartSnortMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12V\n\x1bstartSnortIdsMonitorThreads\x12\x1f.StartSnortIdsMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astartSnortIdsMonitorThread\x12\x1e.StartSnortIdsMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15startSnortIdsManagers\x12\x19.StartSnortIdsManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14stopSnortIdsManagers\x12\x18.StopSnortIdsManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14startSnortIdsManager\x12\x18.StartSnortIdsManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x46\n\x13stopSnortIdsManager\x12\x17.StopSnortIdsManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astopSnortIdsMonitorThreads\x12\x1e.StopSnortIdsMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12m\n getSnortIdsMonitorThreadStatuses\x12$.GetSnortIdsMonitorThreadStatusesMsg\x1a!.SnortIdsMonitorThreadStatusesDTO\"\x00\x12R\n\x17getSnortIdsManagersInfo\x12\x1b.GetSnortIdsManagersInfoMsg\x1a\x18.SnortIdsManagersInfoDTO\"\x00\x12=\n\x10getExecutionInfo\x12\x14.GetExecutionInfoMsg\x1a\x11.ExecutionInfoDTO\"\x00\x12?\n\x11listKibanaTunnels\x12\x15.ListKibanaTunnelsMsg\x1a\x11.KibanaTunnelsDTO\"\x00\x12\x44\n\x12\x63reateKibanaTunnel\x12\x16.CreateKibanaTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0elistRyuTunnels\x12\x12.ListRyuTunnelsMsg\x1a\x0e.RyuTunnelsDTO\"\x00\x12\x41\n\x0f\x63reateRyuTunnel\x12\x16.CreateKibanaTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12removeKibanaTunnel\x12\x16.RemoveKibanaTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fremoveRyuTunnel\x12\x13.RemoveRyuTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16stopHostMonitorThreads\x12\x1a.StopHostMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15stopHostMonitorThread\x12\x19.StopHostMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x0fstartRyuMonitor\x12\x19.StartRyuMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x0estopRyuMonitor\x12\x18.StopRyuMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x14getRyuControllerLogs\x12\x18.GetRyuControllerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x36\n\x11getRyuManagerLogs\x12\x15.GetRyuManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12(\n\ngetElkLogs\x12\x0e.GetElkLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x36\n\x11getElkManagerLogs\x12\x15.GetElkManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12>\n\x15getTrafficManagerLogs\x12\x19.GetTrafficManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x38\n\x12getHostManagerLogs\x12\x16.GetHostManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x32\n\x0fgetOSSECIdsLogs\x12\x13.GetOSSECIdsLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x43\n\x19getOSSECIdsManagerLogsMsg\x12\x1a.GetOSSECIdsManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x32\n\x0fgetSnortIdsLogs\x12\x13.GetSnortIdsLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x43\n\x19getSnortIdsManagerLogsMsg\x12\x1a.GetSnortIdsManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12,\n\x0cgetKafkaLogs\x12\x10.GetKafkaLogsMsg\x1a\x08.LogsDTO\"\x00\x12:\n\x13getKafkaManagerLogs\x12\x17.GetKafkaManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12?\n\x17getClientManagerLogsMsg\x12\x18.GetClientManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x34\n\x10getContainerLogs\x12\x14.GetContainerLogsMsg\x1a\x08.LogsDTO\"\x00\x12>\n\x15getClusterManagerLogs\x12\x19.GetClusterManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12^\n\x1agetExecutionTimeSeriesData\x12\x1e.GetExecutionTimeSeriesDataMsg\x1a\x1e.EmulationMetricsTimeSeriesDTO\"\x00\x12\x42\n\x11startSparkServers\x12\x15.StartSparkServersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10stopSparkServers\x12\x14.StopSparkServersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startSparkServer\x12\x14.StartSparkServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopSparkServer\x12\x13.StopSparkServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x30\n\x08\x63heckPid\x12\x0c.CheckPidMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12.\n\x07stopPid\x12\x0b.StopPidMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x46\n\x13start5GCoreManagers\x12\x17.Start5GCoreManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12stop5GCoreManagers\x12\x16.Stop5GCoreManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12start5GCoreManager\x12\x16.Start5GCoreManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11stop5GCoreManager\x12\x15.Stop5GCoreManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0bstop5GCores\x12\x0f.Stop5GCoresMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0cstart5GCores\x12\x10.Start5GCoresMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0binit5GCores\x12\x0f.Init5GCoresMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x34\n\nstop5GCore\x12\x0e.Stop5GCoreMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0bstart5GCore\x12\x0f.Start5GCoreMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x34\n\ninit5GCore\x12\x0e.Init5GCoreMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11start5GCUManagers\x12\x15.Start5GCUManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10stop5GCUManagers\x12\x14.Stop5GCUManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10start5GCUManager\x12\x14.Start5GCUManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstop5GCUManager\x12\x13.Stop5GCUManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstop5GCUs\x12\r.Stop5GCUsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x34\n\nstart5GCUs\x12\x0e.Start5GCUsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x30\n\x08stop5GCU\x12\x0c.Stop5GCUMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstart5GCU\x12\r.Start5GCUMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11start5GDUManagers\x12\x15.Start5GDUManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10stop5GDUManagers\x12\x14.Stop5GDUManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10start5GDUManager\x12\x14.Start5GDUManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstop5GDUManager\x12\x13.Stop5GDUManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstop5GDUs\x12\r.Stop5GDUsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x34\n\nstart5GDUs\x12\x0e.Start5GDUsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x30\n\x08stop5GDU\x12\x0c.Stop5GDUMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstart5GDU\x12\r.Start5GDUMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstop5GUEs\x12\r.Stop5GUEsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x34\n\nstart5GUEs\x12\x0e.Start5GUEsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x30\n\x08stop5GUE\x12\x0c.Stop5GUEMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstart5GUE\x12\r.Start5GUEMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tinit5GUEs\x12\r.Init5GUEsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x30\n\x08init5GUE\x12\x0c.Init5GUEMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12O\n\x15get5GCoreManagersInfo\x12\x19.Get5GCoreManagersInfoMsg\x1a\x19.FiveGCoreManagersInfoDTO\"\x00\x12I\n\x13get5GCUManagersInfo\x12\x17.Get5GCUManagersInfoMsg\x1a\x17.FiveGCUManagersInfoDTO\"\x00\x12I\n\x13get5GDUManagersInfo\x12\x17.Get5GDUManagersInfoMsg\x1a\x17.FiveGDUManagersInfoDTO\"\x00\x12<\n\x14get5GCoreManagerLogs\x12\x18.Get5GCoreManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x38\n\x12get5GCUManagerLogs\x12\x16.Get5GCUManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x38\n\x12get5GDUManagerLogs\x12\x16.Get5GDUManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12.\n\rget5GCoreLogs\x12\x11.Get5GCoreLogsMsg\x1a\x08.LogsDTO\"\x00\x12*\n\x0bget5GCULogs\x12\x0f.Get5GCULogsMsg\x1a\x08.LogsDTO\"\x00\x12*\n\x0bget5GDULogs\x12\x0f.Get5GDULogsMsg\x1a\x08.LogsDTO\"\x00\x12*\n\x0bget5GUELogs\x12\x0f.Get5GUELogsMsg\x1a\x08.LogsDTO\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cluster_manager_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STOPPIDMSG']._serialized_start=25
  _globals['_STOPPIDMSG']._serialized_end=50
  _globals['_CHECKPIDMSG']._serialized_start=52
  _globals['_CHECKPIDMSG']._serialized_end=78
  _globals['_STARTSPARKSERVERMSG']._serialized_start=80
  _globals['_STARTSPARKSERVERMSG']._serialized_end=163
  _globals['_STOPSPARKSERVERMSG']._serialized_start=165
  _globals['_STOPSPARKSERVERMSG']._serialized_end=247
  _globals['_STARTSPARKSERVERSMSG']._serialized_start=249
  _globals['_STARTSPARKSERVERSMSG']._serialized_end=312
  _globals['_STOPSPARKSERVERSMSG']._serialized_start=314
  _globals['_STOPSPARKSERVERSMSG']._serialized_end=376
  _globals['_GETEXECUTIONTIMESERIESDATAMSG']._serialized_start=378
  _globals['_GETEXECUTIONTIMESERIESDATAMSG']._serialized_end=467
  _globals['_EMULATIONMETRICSTIMESERIESDTO']._serialized_start=470
  _globals['_EMULATIONMETRICSTIMESERIESDTO']._serialized_end=1911
  _globals['_AVGPORTSTATISTICDICT']._serialized_start=1913
  _globals['_AVGPORTSTATISTICDICT']._serialized_end=1984
  _globals['_AGGFLOWSTATISTICDICT']._serialized_start=1986
  _globals['_AGGFLOWSTATISTICDICT']._serialized_end=2057
  _globals['_AVGFLOWSTATISTICDICT']._serialized_start=2059
  _globals['_AVGFLOWSTATISTICDICT']._serialized_end=2130
  _globals['_PORTSTATISTICDICT']._serialized_start=2132
  _globals['_PORTSTATISTICDICT']._serialized_end=2197
  _globals['_FLOWSTATISTICDICT']._serialized_start=2199
  _globals['_FLOWSTATISTICDICT']._serialized_end=2264
  _globals['_OSSECIDSALERTCOUNTERSDICT']._serialized_start=2266
  _globals['_OSSECIDSALERTCOUNTERSDICT']._serialized_end=2347
  _globals['_HOSTMETRICSDICT']._serialized_start=2349
  _globals['_HOSTMETRICSDICT']._serialized_end=2414
  _globals['_DOCKERSTATSDICT']._serialized_start=2416
  _globals['_DOCKERSTATSDICT']._serialized_end=2477
  _globals['_AVGPORTSTATISTICDTO']._serialized_start=2480
  _globals['_AVGPORTSTATISTICDTO']._serialized_end=3052
  _globals['_AVGFLOWSTATISTICDTO']._serialized_start=3055
  _globals['_AVGFLOWSTATISTICDTO']._serialized_end=3326
  _globals['_AGGFLOWSTATISTICDTO']._serialized_start=3329
  _globals['_AGGFLOWSTATISTICDTO']._serialized_end=3467
  _globals['_PORTSTATISTICDTO']._serialized_start=3470
  _globals['_PORTSTATISTICDTO']._serialized_end=3973
  _globals['_FLOWSTATISTICDTO']._serialized_start=3976
  _globals['_FLOWSTATISTICDTO']._serialized_end=4268
  _globals['_OSSECIDSALERTCOUNTERSDTO']._serialized_start=4271
  _globals['_OSSECIDSALERTCOUNTERSDTO']._serialized_end=4468
  _globals['_SNORTIDSALERTCOUNTERSDTO']._serialized_start=4471
  _globals['_SNORTIDSALERTCOUNTERSDTO']._serialized_end=4652
  _globals['_SNORTIDSIPALERTCOUNTERSDICT']._serialized_start=4654
  _globals['_SNORTIDSIPALERTCOUNTERSDICT']._serialized_end=4739
  _globals['_SNORTIDSALERTCOUNTERSDICT']._serialized_start=4741
  _globals['_SNORTIDSALERTCOUNTERSDICT']._serialized_end=4822
  _globals['_SNORTIDSRULECOUNTERSDICT']._serialized_start=4824
  _globals['_SNORTIDSRULECOUNTERSDICT']._serialized_end=4903
  _globals['_SNORTIDSIPALERTCOUNTERSDTO']._serialized_start=4906
  _globals['_SNORTIDSIPALERTCOUNTERSDTO']._serialized_end=5107
  _globals['_SNORTIDSRULECOUNTERSDTO']._serialized_start=5109
  _globals['_SNORTIDSRULECOUNTERSDTO']._serialized_end=5203
  _globals['_EMULATIONATTACKERACTIONDTO']._serialized_start=5206
  _globals['_EMULATIONATTACKERACTIONDTO']._serialized_end=5450
  _globals['_EMULATIONDEFENDERACTIONDTO']._serialized_start=5453
  _globals['_EMULATIONDEFENDERACTIONDTO']._serialized_end=5656
  _globals['_HOSTMETRICSDATADTO']._serialized_start=5659
  _globals['_HOSTMETRICSDATADTO']._serialized_end=5865
  _globals['_DOCKERSTATSDTO']._serialized_start=5868
  _globals['_DOCKERSTATSDTO']._serialized_end=6116
  _globals['_CLIENTPOPULATIONMETRICSDTO']._serialized_start=6118
  _globals['_CLIENTPOPULATIONMETRICSDTO']._serialized_end=6227
  _globals['_GETCLUSTERMANAGERLOGSMSG']._serialized_start=6229
  _globals['_GETCLUSTERMANAGERLOGSMSG']._serialized_end=6255
  _globals['_GETCONTAINERLOGSMSG']._serialized_start=6257
  _globals['_GETCONTAINERLOGSMSG']._serialized_end=6340
  _globals['_GETCLIENTMANAGERLOGSMSG']._serialized_start=6342
  _globals['_GETCLIENTMANAGERLOGSMSG']._serialized_end=6408
  _globals['_GETKAFKAMANAGERLOGSMSG']._serialized_start=6410
  _globals['_GETKAFKAMANAGERLOGSMSG']._serialized_end=6475
  _globals['_GETKAFKALOGSMSG']._serialized_start=6477
  _globals['_GETKAFKALOGSMSG']._serialized_end=6535
  _globals['_GETSNORTIDSLOGSMSG']._serialized_start=6537
  _globals['_GETSNORTIDSLOGSMSG']._serialized_end=6619
  _globals['_GETSNORTIDSMANAGERLOGSMSG']._serialized_start=6621
  _globals['_GETSNORTIDSMANAGERLOGSMSG']._serialized_end=6710
  _globals['_GETOSSECIDSMANAGERLOGSMSG']._serialized_start=6712
  _globals['_GETOSSECIDSMANAGERLOGSMSG']._serialized_end=6801
  _globals['_GETOSSECIDSLOGSMSG']._serialized_start=6803
  _globals['_GETOSSECIDSLOGSMSG']._serialized_end=6885
  _globals['_GETHOSTMANAGERLOGSMSG']._serialized_start=6887
  _globals['_GETHOSTMANAGERLOGSMSG']._serialized_end=6972
  _globals['_GETTRAFFICMANAGERLOGSMSG']._serialized_start=6974
  _globals['_GETTRAFFICMANAGERLOGSMSG']._serialized_end=7062
  _globals['_GETELKMANAGERLOGSMSG']._serialized_start=7064
  _globals['_GETELKMANAGERLOGSMSG']._serialized_end=7127
  _globals['_GETELKLOGSMSG']._serialized_start=7129
  _globals['_GETELKLOGSMSG']._serialized_end=7185
  _globals['_GETRYUMANAGERLOGSMSG']._serialized_start=7187
  _globals['_GETRYUMANAGERLOGSMSG']._serialized_end=7250
  _globals['_GETRYUCONTROLLERLOGSMSG']._serialized_start=7252
  _globals['_GETRYUCONTROLLERLOGSMSG']._serialized_end=7318
  _globals['_STOPRYUMONITORTHREADMSG']._serialized_start=7320
  _globals['_STOPRYUMONITORTHREADMSG']._serialized_end=7386
  _globals['_STARTRYUMONITORTHREADMSG']._serialized_start=7388
  _globals['_STARTRYUMONITORTHREADMSG']._serialized_end=7455
  _globals['_STOPHOSTMONITORTHREADSMSG']._serialized_start=7457
  _globals['_STOPHOSTMONITORTHREADSMSG']._serialized_end=7525
  _globals['_STOPHOSTMONITORTHREADMSG']._serialized_start=7527
  _globals['_STOPHOSTMONITORTHREADMSG']._serialized_end=7615
  _globals['_REMOVEKIBANATUNNELMSG']._serialized_start=7617
  _globals['_REMOVEKIBANATUNNELMSG']._serialized_end=7681
  _globals['_CREATEKIBANATUNNELMSG']._serialized_start=7683
  _globals['_CREATEKIBANATUNNELMSG']._serialized_end=7747
  _globals['_LISTKIBANATUNNELSMSG']._serialized_start=7749
  _globals['_LISTKIBANATUNNELSMSG']._serialized_end=7771
  _globals['_KIBANATUNNELSDTO']._serialized_start=7773
  _globals['_KIBANATUNNELSDTO']._serialized_end=7826
  _globals['_KIBANATUNNELDTO']._serialized_start=7828
  _globals['_KIBANATUNNELDTO']._serialized_end=7912
  _globals['_REMOVERYUTUNNELMSG']._serialized_start=7914
  _globals['_REMOVERYUTUNNELMSG']._serialized_end=7975
  _globals['_CREATERYUTUNNELMSG']._serialized_start=7977
  _globals['_CREATERYUTUNNELMSG']._serialized_end=8038
  _globals['_LISTRYUTUNNELSMSG']._serialized_start=8040
  _globals['_LISTRYUTUNNELSMSG']._serialized_end=8059
  _globals['_RYUTUNNELSDTO']._serialized_start=8061
  _globals['_RYUTUNNELSDTO']._serialized_end=8108
  _globals['_RYUTUNNELDTO']._serialized_start=8110
  _globals['_RYUTUNNELDTO']._serialized_end=8191
  _globals['_SNORTIDSMONITORTHREADSTATUSESDTO']._serialized_start=8193
  _globals['_SNORTIDSMONITORTHREADSTATUSESDTO']._serialized_end=8273
  _globals['_GETSNORTIDSMANAGERSINFOMSG']._serialized_start=8275
  _globals['_GETSNORTIDSMANAGERSINFOMSG']._serialized_end=8344
  _globals['_GETSNORTIDSMONITORTHREADSTATUSESMSG']._serialized_start=8346
  _globals['_GETSNORTIDSMONITORTHREADSTATUSESMSG']._serialized_end=8424
  _globals['_STOPSNORTIDSMONITORTHREADSMSG']._serialized_start=8426
  _globals['_STOPSNORTIDSMONITORTHREADSMSG']._serialized_end=8498
  _globals['_STOPSNORTIDSMANAGERMSG']._serialized_start=8500
  _globals['_STOPSNORTIDSMANAGERMSG']._serialized_end=8586
  _globals['_STARTSNORTIDSMANAGERMSG']._serialized_start=8588
  _globals['_STARTSNORTIDSMANAGERMSG']._serialized_end=8675
  _globals['_STOPSNORTIDSMANAGERSMSG']._serialized_start=8677
  _globals['_STOPSNORTIDSMANAGERSMSG']._serialized_end=8743
  _globals['_STARTSNORTIDSMANAGERSMSG']._serialized_start=8745
  _globals['_STARTSNORTIDSMANAGERSMSG']._serialized_end=8812
  _globals['_STARTSNORTMSG']._serialized_start=8814
  _globals['_STARTSNORTMSG']._serialized_end=8891
  _globals['_STARTSNORTIDSMONITORTHREADMSG']._serialized_start=8893
  _globals['_STARTSNORTIDSMONITORTHREADMSG']._serialized_end=8986
  _globals['_STARTSNORTIDSMONITORTHREADSMSG']._serialized_start=8988
  _globals['_STARTSNORTIDSMONITORTHREADSMSG']._serialized_end=9061
  _globals['_STOPSNORTMSG']._serialized_start=9063
  _globals['_STOPSNORTMSG']._serialized_end=9139
  _globals['_STOPSNORTIDSMONITORTHREADMSG']._serialized_start=9141
  _globals['_STOPSNORTIDSMONITORTHREADMSG']._serialized_end=9233
  _globals['_STOPSNORTIDSESMSG']._serialized_start=9235
  _globals['_STOPSNORTIDSESMSG']._serialized_end=9295
  _globals['_STOPSNORTIDSESMONITORTHREADSMSG']._serialized_start=9297
  _globals['_STOPSNORTIDSESMONITORTHREADSMSG']._serialized_end=9371
  _globals['_GETRYUMANAGERSINFOMSG']._serialized_start=9373
  _globals['_GETRYUMANAGERSINFOMSG']._serialized_end=9437
  _globals['_STOPRYUMONITORSERVICEMSG']._serialized_start=9439
  _globals['_STOPRYUMONITORSERVICEMSG']._serialized_end=9506
  _globals['_STARTRYUMONITORSERVICEMSG']._serialized_start=9508
  _globals['_STARTRYUMONITORSERVICEMSG']._serialized_end=9576
  _globals['_STOPRYUSERVICEMSG']._serialized_start=9578
  _globals['_STOPRYUSERVICEMSG']._serialized_end=9638
  _globals['_STARTRYUSERVICEMSG']._serialized_start=9640
  _globals['_STARTRYUSERVICEMSG']._serialized_end=9701
  _globals['_GETRYUSERVICESTATUSMSG']._serialized_start=9703
  _globals['_GETRYUSERVICESTATUSMSG']._serialized_end=9768
  _globals['_STOPRYUMANAGERMSG']._serialized_start=9770
  _globals['_STOPRYUMANAGERMSG']._serialized_end=9830
  _globals['_STARTRYUMANAGERMSG']._serialized_start=9832
  _globals['_STARTRYUMANAGERMSG']._serialized_end=9893
  _globals['_GETOSSECIDSMANAGERSINFOMSG']._serialized_start=9895
  _globals['_GETOSSECIDSMANAGERSINFOMSG']._serialized_end=9964
  _globals['_OSSECIDSMONITORTHREADSTATUSESDTO']._serialized_start=9966
  _globals['_OSSECIDSMONITORTHREADSTATUSESDTO']._serialized_end=10046
  _globals['_GETOSSECIDSMONITORTHREADSTATUSESMSG']._serialized_start=10048
  _globals['_GETOSSECIDSMONITORTHREADSTATUSESMSG']._serialized_end=10126
  _globals['_STOPOSSECIDSMONITORTHREADSMSG']._serialized_start=10128
  _globals['_STOPOSSECIDSMONITORTHREADSMSG']._serialized_end=10200
  _globals['_STOPOSSECIDSMONITORTHREADMSG']._serialized_start=10202
  _globals['_STOPOSSECIDSMONITORTHREADMSG']._serialized_end=10294
  _globals['_STARTOSSECIDSMONITORTHREADMSG']._serialized_start=10296
  _globals['_STARTOSSECIDSMONITORTHREADMSG']._serialized_end=10389
  _globals['_STOPOSSECIDSMANAGER']._serialized_start=10391
  _globals['_STOPOSSECIDSMANAGER']._serialized_end=10474
  _globals['_STARTOSSECIDSMANAGER']._serialized_start=10476
  _globals['_STARTOSSECIDSMANAGER']._serialized_end=10560
  _globals['_STOPOSSECIDSMANAGERS']._serialized_start=10562
  _globals['_STOPOSSECIDSMANAGERS']._serialized_end=10625
  _globals['_STARTOSSECIDSMANAGERS']._serialized_start=10627
  _globals['_STARTOSSECIDSMANAGERS']._serialized_end=10691
  _globals['_STARTOSSECIDSMSG']._serialized_start=10693
  _globals['_STARTOSSECIDSMSG']._serialized_end=10773
  _globals['_STOPOSSECIDSMSG']._serialized_start=10775
  _globals['_STOPOSSECIDSMSG']._serialized_end=10854
  _globals['_STARTOSSECIDSESMSG']._serialized_start=10856
  _globals['_STARTOSSECIDSESMSG']._serialized_end=10917
  _globals['_STOPOSSECIDSESMSG']._serialized_start=10919
  _globals['_STOPOSSECIDSESMSG']._serialized_end=10979
  _globals['_GETKAFKAMANAGERSINFOMSG']._serialized_start=10981
  _globals['_GETKAFKAMANAGERSINFOMSG']._serialized_end=11047
  _globals['_STARTKAFKASERVERMSG']._serialized_start=11049
  _globals['_STARTKAFKASERVERMSG']._serialized_end=11111
  _globals['_STOPKAFKASERVERMSG']._serialized_start=11113
  _globals['_STOPKAFKASERVERMSG']._serialized_end=11174
  _globals['_GETKAFKAMANAGERSTATUSMSG']._serialized_start=11176
  _globals['_GETKAFKAMANAGERSTATUSMSG']._serialized_end=11243
  _globals['_CREATEKAFKATOPICSMSG']._serialized_start=11245
  _globals['_CREATEKAFKATOPICSMSG']._serialized_end=11308
  _globals['_STOPKAFKAMANAGERMSG']._serialized_start=11310
  _globals['_STOPKAFKAMANAGERMSG']._serialized_end=11372
  _globals['_STARTKAFKAMANAGERMSG']._serialized_start=11374
  _globals['_STARTKAFKAMANAGERMSG']._serialized_end=11437
  _globals['_GETHOSTMANAGERSINFOMSG']._serialized_start=11439
  _globals['_GETHOSTMANAGERSINFOMSG']._serialized_end=11504
  _globals['_GETHOSTMONITORTHREADSSTATUSESMSG']._serialized_start=11506
  _globals['_GETHOSTMONITORTHREADSSTATUSESMSG']._serialized_end=11581
  _globals['_APPLYFILEBEATCONFIGMSG']._serialized_start=11583
  _globals['_APPLYFILEBEATCONFIGMSG']._serialized_end=11669
  _globals['_APPLYPACKETBEATCONFIGMSG']._serialized_start=11671
  _globals['_APPLYPACKETBEATCONFIGMSG']._serialized_end=11759
  _globals['_APPLYMETRICBEATCONFIGMSG']._serialized_start=11761
  _globals['_APPLYMETRICBEATCONFIGMSG']._serialized_end=11849
  _globals['_APPLYHEARTBEATCONFIGMSG']._serialized_start=11851
  _globals['_APPLYHEARTBEATCONFIGMSG']._serialized_end=11938
  _globals['_STOPFILEBEATMSG']._serialized_start=11940
  _globals['_STOPFILEBEATMSG']._serialized_end=12019
  _globals['_STOPPACKETBEATMSG']._serialized_start=12021
  _globals['_STOPPACKETBEATMSG']._serialized_end=12102
  _globals['_STOPMETRICBEATMSG']._serialized_start=12104
  _globals['_STOPMETRICBEATMSG']._serialized_end=12185
  _globals['_STOPHEARTBEATMSG']._serialized_start=12187
  _globals['_STOPHEARTBEATMSG']._serialized_end=12267
  _globals['_STARTFILEBEATMSG']._serialized_start=12269
  _globals['_STARTFILEBEATMSG']._serialized_end=12371
  _globals['_STARTPACKETBEATMSG']._serialized_start=12373
  _globals['_STARTPACKETBEATMSG']._serialized_end=12477
  _globals['_STARTMETRICBEATMSG']._serialized_start=12479
  _globals['_STARTMETRICBEATMSG']._serialized_end=12583
  _globals['_STARTHEARTBEATMSG']._serialized_start=12585
  _globals['_STARTHEARTBEATMSG']._serialized_end=12688
  _globals['_STARTHOSTMONITORTHREADMSG']._serialized_start=12690
  _globals['_STARTHOSTMONITORTHREADMSG']._serialized_end=12779
  _globals['_STOPHEARTBEATSMSG']._serialized_start=12781
  _globals['_STOPHEARTBEATSMSG']._serialized_end=12841
  _globals['_STOPPACKETBEATSMSG']._serialized_start=12843
  _globals['_STOPPACKETBEATSMSG']._serialized_end=12904
  _globals['_STOPFILEBEATSMSG']._serialized_start=12906
  _globals['_STOPFILEBEATSMSG']._serialized_end=12965
  _globals['_STOPMETRICBEATSMSG']._serialized_start=12967
  _globals['_STOPMETRICBEATSMSG']._serialized_end=13028
  _globals['_STARTHOSTMONITORTHREADSMSG']._serialized_start=13030
  _globals['_STARTHOSTMONITORTHREADSMSG']._serialized_end=13099
  _globals['_STOPHOSTMANAGERMSG']._serialized_start=13101
  _globals['_STOPHOSTMANAGERMSG']._serialized_end=13183
  _globals['_STARTHOSTMANAGERMSG']._serialized_start=13185
  _globals['_STARTHOSTMANAGERMSG']._serialized_end=13268
  _globals['_STOPHOSTMANAGERSMSG']._serialized_start=13270
  _globals['_STOPHOSTMANAGERSMSG']._serialized_end=13332
  _globals['_EXECUTIONINFODTO']._serialized_start=13335
  _globals['_EXECUTIONINFODTO']._serialized_end=14195
  _globals['_RYUMANAGERSINFODTO']._serialized_start=14198
  _globals['_RYUMANAGERSINFODTO']._serialized_end=14427
  _globals['_RYUMANAGERSTATUSDTO']._serialized_start=14430
  _globals['_RYUMANAGERSTATUSDTO']._serialized_end=14610
  _globals['_HOSTMANAGERSINFODTO']._serialized_start=14613
  _globals['_HOSTMANAGERSINFODTO']._serialized_end=14788
  _globals['_HOSTMANAGERSTATUSESDTO']._serialized_start=14790
  _globals['_HOSTMANAGERSTATUSESDTO']._serialized_end=14866
  _globals['_HOSTMANAGERSTATUSDTO']._serialized_start=14869
  _globals['_HOSTMANAGERSTATUSDTO']._serialized_end=15037
  _globals['_KAFKAMANAGERSINFODTO']._serialized_start=15040
  _globals['_KAFKAMANAGERSINFODTO']._serialized_end=15212
  _globals['_KAFKASTATUSDTO']._serialized_start=15214
  _globals['_KAFKASTATUSDTO']._serialized_end=15263
  _globals['_OSSECIDSMANAGERSINFODTO']._serialized_start=15266
  _globals['_OSSECIDSMANAGERSINFODTO']._serialized_end=15450
  _globals['_OSSECIDSSTATUSDTO']._serialized_start=15452
  _globals['_OSSECIDSSTATUSDTO']._serialized_end=15523
  _globals['_SNORTIDSMANAGERSINFODTO']._serialized_start=15526
  _globals['_SNORTIDSMANAGERSINFODTO']._serialized_end=15710
  _globals['_SNORTIDSSTATUSDTO']._serialized_start=15712
  _globals['_SNORTIDSSTATUSDTO']._serialized_end=15783
  _globals['_GETEXECUTIONINFOMSG']._serialized_start=15785
  _globals['_GETEXECUTIONINFOMSG']._serialized_end=15847
  _globals['_STOPCONTAINERSOFEXECUTIONMSG']._serialized_start=15849
  _globals['_STOPCONTAINERSOFEXECUTIONMSG']._serialized_end=15920
  _globals['_RUNCONTAINERMSG']._serialized_start=15922
  _globals['_RUNCONTAINERMSG']._serialized_end=16043
  _globals['_STARTCONTAINERSOFEXECUTIONMSG']._serialized_start=16045
  _globals['_STARTCONTAINERSOFEXECUTIONMSG']._serialized_end=16117
  _globals['_GETELKMANAGERSINFOMSG']._serialized_start=16119
  _globals['_GETELKMANAGERSINFOMSG']._serialized_end=16183
  _globals['_ELKMANAGERSINFODTO']._serialized_start=16186
  _globals['_ELKMANAGERSINFODTO']._serialized_end=16401
  _globals['_STOPLOGSTASHSERVICEMSG']._serialized_start=16403
  _globals['_STOPLOGSTASHSERVICEMSG']._serialized_end=16468
  _globals['_STARTLOGSTASHSERVICEMSG']._serialized_start=16470
  _globals['_STARTLOGSTASHSERVICEMSG']._serialized_end=16536
  _globals['_STOPKIBANASERVICEMSG']._serialized_start=16538
  _globals['_STOPKIBANASERVICEMSG']._serialized_end=16601
  _globals['_STARTKIBANASERVICEMSG']._serialized_start=16603
  _globals['_STARTKIBANASERVICEMSG']._serialized_end=16667
  _globals['_STOPELASTICSERVICEMSG']._serialized_start=16669
  _globals['_STOPELASTICSERVICEMSG']._serialized_end=16733
  _globals['_STARTELASTICSERVICEMSG']._serialized_start=16735
  _globals['_STARTELASTICSERVICEMSG']._serialized_end=16800
  _globals['_STOPELKSTACKMSG']._serialized_start=16802
  _globals['_STOPELKSTACKMSG']._serialized_end=16860
  _globals['_ELKSTATUSDTO']._serialized_start=16862
  _globals['_ELKSTATUSDTO']._serialized_end=16948
  _globals['_GETELKSTACKSTATUSMSG']._serialized_start=16950
  _globals['_GETELKSTACKSTATUSMSG']._serialized_end=17013
  _globals['_STOPELKMANAGERMSG']._serialized_start=17015
  _globals['_STOPELKMANAGERMSG']._serialized_end=17075
  _globals['_STARTELKMANAGERMSG']._serialized_start=17077
  _globals['_STARTELKMANAGERMSG']._serialized_end=17138
  _globals['_GETDOCKERSTATSMANAGERSINFOMSG']._serialized_start=17140
  _globals['_GETDOCKERSTATSMANAGERSINFOMSG']._serialized_end=17212
  _globals['_DOCKERSTATSMANAGERSINFODTO']._serialized_start=17215
  _globals['_DOCKERSTATSMANAGERSINFODTO']._serialized_end=17418
  _globals['_REMOVEALLDOCKERNETWORKSMSG']._serialized_start=17420
  _globals['_REMOVEALLDOCKERNETWORKSMSG']._serialized_end=17448
  _globals['_REMOVEDOCKERNETWORKSMSG']._serialized_start=17450
  _globals['_REMOVEDOCKERNETWORKSMSG']._serialized_end=17493
  _globals['_DOCKERSTATSMONITORSTATUSDTO']._serialized_start=17495
  _globals['_DOCKERSTATSMONITORSTATUSDTO']._serialized_end=17596
  _globals['_GETDOCKERSTATSMANAGERSTATUSMSG']._serialized_start=17598
  _globals['_GETDOCKERSTATSMANAGERSTATUSMSG']._serialized_end=17644
  _globals['_STOPDOCKERSTATSMANAGERTHREADMSG']._serialized_start=17646
  _globals['_STOPDOCKERSTATSMANAGERTHREADMSG']._serialized_end=17720
  _globals['_CREATEEMULATIONNETWORKSMSG']._serialized_start=17722
  _globals['_CREATEEMULATIONNETWORKSMSG']._serialized_end=17791
  _globals['_LISTALLSTOPPEDCONTAINERSMSG']._serialized_start=17793
  _globals['_LISTALLSTOPPEDCONTAINERSMSG']._serialized_end=17822
  _globals['_STOPPEDCONTAINERSDTO']._serialized_start=17824
  _globals['_STOPPEDCONTAINERSDTO']._serialized_end=17894
  _globals['_LISTALLRUNNINGEMULATIONSMSG']._serialized_start=17896
  _globals['_LISTALLRUNNINGEMULATIONSMSG']._serialized_end=17925
  _globals['_RUNNINGEMULATIONSDTO']._serialized_start=17927
  _globals['_RUNNINGEMULATIONSDTO']._serialized_end=17976
  _globals['_LISTALLRUNNINGCONTAINERSMSG']._serialized_start=17978
  _globals['_LISTALLRUNNINGCONTAINERSMSG']._serialized_end=18007
  _globals['_RUNNINGCONTAINERSDTO']._serialized_start=18009
  _globals['_RUNNINGCONTAINERSDTO']._serialized_end=18079
  _globals['_DOCKERCONTAINERDTO']._serialized_start=18081
  _globals['_DOCKERCONTAINERDTO']._serialized_end=18142
  _globals['_STARTCONTAINERMSG']._serialized_start=18144
  _globals['_STARTCONTAINERMSG']._serialized_end=18177
  _globals['_STARTALLSTOPPEDCONTAINERSMSG']._serialized_start=18179
  _globals['_STARTALLSTOPPEDCONTAINERSMSG']._serialized_end=18209
  _globals['_LISTALLDOCKERNETWORKSMSG']._serialized_start=18211
  _globals['_LISTALLDOCKERNETWORKSMSG']._serialized_end=18237
  _globals['_DOCKERNETWORKSDTO']._serialized_start=18239
  _globals['_DOCKERNETWORKSDTO']._serialized_end=18297
  _globals['_CONTAINERIMAGESDTO']._serialized_start=18299
  _globals['_CONTAINERIMAGESDTO']._serialized_end=18355
  _globals['_CONTAINERIMAGEDTO']._serialized_start=18357
  _globals['_CONTAINERIMAGEDTO']._serialized_end=18459
  _globals['_LISTALLCONTAINERIMAGESMSG']._serialized_start=18461
  _globals['_LISTALLCONTAINERIMAGESMSG']._serialized_end=18488
  _globals['_REMOVECONTAINERIMAGEMSG']._serialized_start=18490
  _globals['_REMOVECONTAINERIMAGEMSG']._serialized_end=18529
  _globals['_REMOVEALLCONTAINERIMAGESMSG']._serialized_start=18531
  _globals['_REMOVEALLCONTAINERIMAGESMSG']._serialized_end=18560
  _globals['_REMOVEALLSTOPPEDCONTAINERSMSG']._serialized_start=18562
  _globals['_REMOVEALLSTOPPEDCONTAINERSMSG']._serialized_end=18593
  _globals['_REMOVECONTAINERMSG']._serialized_start=18595
  _globals['_REMOVECONTAINERMSG']._serialized_end=18629
  _globals['_STOPCONTAINERMSG']._serialized_start=18631
  _globals['_STOPCONTAINERMSG']._serialized_end=18663
  _globals['_STOPALLRUNNINGCONTAINERSMSG']._serialized_start=18665
  _globals['_STOPALLRUNNINGCONTAINERSMSG']._serialized_end=18694
  _globals['_GETTRAFFICMANAGERSINFOMSG']._serialized_start=18696
  _globals['_GETTRAFFICMANAGERSINFOMSG']._serialized_end=18764
  _globals['_TRAFFICMANAGERSINFODTO']._serialized_start=18767
  _globals['_TRAFFICMANAGERSINFODTO']._serialized_end=18952
  _globals['_TRAFFICMANAGERINFODTO']._serialized_start=18954
  _globals['_TRAFFICMANAGERINFODTO']._serialized_end=19010
  _globals['_CLIENTMANAGERSINFODTO']._serialized_start=19013
  _globals['_CLIENTMANAGERSINFODTO']._serialized_end=19190
  _globals['_GETCLIENTMANAGERSINFOMSG']._serialized_start=19192
  _globals['_GETCLIENTMANAGERSINFOMSG']._serialized_end=19259
  _globals['_STARTTRAFFICGENERATORMSG']._serialized_start=19261
  _globals['_STARTTRAFFICGENERATORMSG']._serialized_end=19349
  _globals['_STOPTRAFFICGENERATORMSG']._serialized_start=19351
  _globals['_STOPTRAFFICGENERATORMSG']._serialized_end=19438
  _globals['_STOPTRAFFICGENERATORSMSG']._serialized_start=19440
  _globals['_STOPTRAFFICGENERATORSMSG']._serialized_end=19507
  _globals['_GETNUMCLIENTSDTO']._serialized_start=19510
  _globals['_GETNUMCLIENTSDTO']._serialized_end=19684
  _globals['_GETNUMACTIVECLIENTSMSG']._serialized_start=19686
  _globals['_GETNUMACTIVECLIENTSMSG']._serialized_end=19751
  _globals['_STOPCLIENTPOPULATIONMSG']._serialized_start=19753
  _globals['_STOPCLIENTPOPULATIONMSG']._serialized_end=19819
  _globals['_STOPCLIENTMANAGERMSG']._serialized_start=19821
  _globals['_STOPCLIENTMANAGERMSG']._serialized_end=19884
  _globals['_STARTCLIENTMANAGERMSG']._serialized_start=19886
  _globals['_STARTCLIENTMANAGERMSG']._serialized_end=19950
  _globals['_STOPTRAFFICMANAGERSMSG']._serialized_start=19952
  _globals['_STOPTRAFFICMANAGERSMSG']._serialized_end=20017
  _globals['_STOPTRAFFICMANAGERMSG']._serialized_start=20019
  _globals['_STOPTRAFFICMANAGERMSG']._serialized_end=20104
  _globals['_STARTTRAFFICMANAGERMSG']._serialized_start=20106
  _globals['_STARTTRAFFICMANAGERMSG']._serialized_end=20192
  _globals['_CLEANALLEXECUTIONSMSG']._serialized_start=20194
  _globals['_CLEANALLEXECUTIONSMSG']._serialized_end=20217
  _globals['_STOPALLEXECUTIONSMSG']._serialized_start=20219
  _globals['_STOPALLEXECUTIONSMSG']._serialized_end=20241
  _globals['_STOPEXECUTIONMSG']._serialized_start=20243
  _globals['_STOPEXECUTIONMSG']._serialized_end=20302
  _globals['_CLEANEXECUTIONMSG']._serialized_start=20304
  _globals['_CLEANEXECUTIONMSG']._serialized_end=20364
  _globals['_STOPALLEXECUTIONSOFEMULATIONMSG']._serialized_start=20366
  _globals['_STOPALLEXECUTIONSOFEMULATIONMSG']._serialized_end=20418
  _globals['_CLEANALLEXECUTIONSOFEMULATIONMSG']._serialized_start=20420
  _globals['_CLEANALLEXECUTIONSOFEMULATIONMSG']._serialized_end=20473
  _globals['_GETCSLELOGFILESMSG']._serialized_start=20475
  _globals['_GETCSLELOGFILESMSG']._serialized_end=20495
  _globals['_GETLOGFILEMSG']._serialized_start=20497
  _globals['_GETLOGFILEMSG']._serialized_end=20526
  _globals['_STARTCONTAINERSINEXECUTIONMSG']._serialized_start=20528
  _globals['_STARTCONTAINERSINEXECUTIONMSG']._serialized_end=20600
  _globals['_ATTACHCONTAINERSTONETWORKSINEXECUTIONMSG']._serialized_start=20602
  _globals['_ATTACHCONTAINERSTONETWORKSINEXECUTIONMSG']._serialized_end=20685
  _globals['_INSTALLLIBRARIESMSG']._serialized_start=20687
  _globals['_INSTALLLIBRARIESMSG']._serialized_end=20749
  _globals['_APPLYKAFKACONFIGMSG']._serialized_start=20751
  _globals['_APPLYKAFKACONFIGMSG']._serialized_end=20813
  _globals['_STARTSDNCONTROLLERMSG']._serialized_start=20815
  _globals['_STARTSDNCONTROLLERMSG']._serialized_end=20879
  _globals['_APPLYRESOUCECONSTRAINTSMSG']._serialized_start=20881
  _globals['_APPLYRESOUCECONSTRAINTSMSG']._serialized_end=20950
  _globals['_CREATEOVSSWITCHESMSG']._serialized_start=20952
  _globals['_CREATEOVSSWITCHESMSG']._serialized_end=21015
  _globals['_PINGEXECUTIONMSG']._serialized_start=21017
  _globals['_PINGEXECUTIONMSG']._serialized_end=21076
  _globals['_CONFIGUREOVSMSG']._serialized_start=21078
  _globals['_CONFIGUREOVSMSG']._serialized_end=21136
  _globals['_STARTSDNCONTROLLERMONITORMSG']._serialized_start=21138
  _globals['_STARTSDNCONTROLLERMONITORMSG']._serialized_end=21209
  _globals['_CREATEUSERSMSG']._serialized_start=21211
  _globals['_CREATEUSERSMSG']._serialized_end=21268
  _globals['_CREATEVULNSMSG']._serialized_start=21270
  _globals['_CREATEVULNSMSG']._serialized_end=21327
  _globals['_CREATEFLAGSMSG']._serialized_start=21329
  _globals['_CREATEFLAGSMSG']._serialized_end=21386
  _globals['_CREATETOPOLOGYMSG']._serialized_start=21388
  _globals['_CREATETOPOLOGYMSG']._serialized_end=21448
  _globals['_STARTTRAFFICMANAGERSMSG']._serialized_start=21450
  _globals['_STARTTRAFFICMANAGERSMSG']._serialized_end=21516
  _globals['_STARTTRAFFICGENERATORSMSG']._serialized_start=21518
  _globals['_STARTTRAFFICGENERATORSMSG']._serialized_end=21586
  _globals['_STARTCLIENTPOPULATIONMSG']._serialized_start=21588
  _globals['_STARTCLIENTPOPULATIONMSG']._serialized_end=21655
  _globals['_STARTKAFKACLIENTPRODUCERMSG']._serialized_start=21657
  _globals['_STARTKAFKACLIENTPRODUCERMSG']._serialized_end=21727
  _globals['_STOPKAFKACLIENTPRODUCERMSG']._serialized_start=21729
  _globals['_STOPKAFKACLIENTPRODUCERMSG']._serialized_end=21798
  _globals['_STARTSNORTIDSESMSG']._serialized_start=21800
  _globals['_STARTSNORTIDSESMSG']._serialized_end=21861
  _globals['_STARTSNORTIDSESMONITORTHREADSMSG']._serialized_start=21863
  _globals['_STARTSNORTIDSESMONITORTHREADSMSG']._serialized_end=21938
  _globals['_STARTOSSECIDSESMSG']._serialized_start=21940
  _globals['_STARTOSSECIDSESMSG']._serialized_end=22001
  _globals['_STARTOSSECIDSESMONITORTHREADSMSG']._serialized_start=22003
  _globals['_STARTOSSECIDSESMONITORTHREADSMSG']._serialized_end=22078
  _globals['_STARTELKSTACKMSG']._serialized_start=22080
  _globals['_STARTELKSTACKMSG']._serialized_end=22139
  _globals['_STARTHOSTMANAGERSMSG']._serialized_start=22141
  _globals['_STARTHOSTMANAGERSMSG']._serialized_end=22204
  _globals['_APPLYFILEBEATCONFIGSMSG']._serialized_start=22206
  _globals['_APPLYFILEBEATCONFIGSMSG']._serialized_end=22272
  _globals['_APPLYPACKETBEATCONFIGSMSG']._serialized_start=22274
  _globals['_APPLYPACKETBEATCONFIGSMSG']._serialized_end=22342
  _globals['_APPLYMETRICBEATCONFIGSMSG']._serialized_start=22344
  _globals['_APPLYMETRICBEATCONFIGSMSG']._serialized_end=22412
  _globals['_APPLYHEARTBEATCONFIGSMSG']._serialized_start=22414
  _globals['_APPLYHEARTBEATCONFIGSMSG']._serialized_end=22481
  _globals['_STARTFILEBEATSMSG']._serialized_start=22483
  _globals['_STARTFILEBEATSMSG']._serialized_end=22565
  _globals['_STARTPACKETBEATSMSG']._serialized_start=22567
  _globals['_STARTPACKETBEATSMSG']._serialized_end=22651
  _globals['_STARTMETRICBEATSMSG']._serialized_start=22653
  _globals['_STARTMETRICBEATSMSG']._serialized_end=22737
  _globals['_STARTHEARTBEATSMSG']._serialized_start=22739
  _globals['_STARTHEARTBEATSMSG']._serialized_end=22822
  _globals['_GETDOCKERSTATSMANAGERLOGSMSG']._serialized_start=22824
  _globals['_GETDOCKERSTATSMANAGERLOGSMSG']._serialized_end=22854
  _globals['_GETPROMETHEUSLOGSMSG']._serialized_start=22856
  _globals['_GETPROMETHEUSLOGSMSG']._serialized_end=22878
  _globals['_GETNODEEXPORTERLOGSMSG']._serialized_start=22880
  _globals['_GETNODEEXPORTERLOGSMSG']._serialized_end=22904
  _globals['_GETCADVISORLOGSMSG']._serialized_start=22906
  _globals['_GETCADVISORLOGSMSG']._serialized_end=22926
  _globals['_GETPGADMINLOGSMSG']._serialized_start=22928
  _globals['_GETPGADMINLOGSMSG']._serialized_end=22947
  _globals['_GETGRAFANALOGSMSG']._serialized_start=22949
  _globals['_GETGRAFANALOGSMSG']._serialized_end=22968
  _globals['_GETNGINXLOGSMSG']._serialized_start=22970
  _globals['_GETNGINXLOGSMSG']._serialized_end=22987
  _globals['_GETDOCKERLOGSMSG']._serialized_start=22989
  _globals['_GETDOCKERLOGSMSG']._serialized_end=23007
  _globals['_GETPOSTGRESQLLOGSMSG']._serialized_start=23009
  _globals['_GETPOSTGRESQLLOGSMSG']._serialized_end=23031
  _globals['_GETFLASKLOGSMSG']._serialized_start=23033
  _globals['_GETFLASKLOGSMSG']._serialized_end=23050
  _globals['_LOGSDTO']._serialized_start=23052
  _globals['_LOGSDTO']._serialized_end=23075
  _globals['_OPERATIONOUTCOMEDTO']._serialized_start=23077
  _globals['_OPERATIONOUTCOMEDTO']._serialized_end=23115
  _globals['_GETNODESTATUSMSG']._serialized_start=23117
  _globals['_GETNODESTATUSMSG']._serialized_end=23135
  _globals['_NODESTATUSDTO']._serialized_start=23138
  _globals['_NODESTATUSDTO']._serialized_end=23445
  _globals['_SERVICESTATUSDTO']._serialized_start=23447
  _globals['_SERVICESTATUSDTO']._serialized_end=23482
  _globals['_STARTPOSTGRESQLMSG']._serialized_start=23484
  _globals['_STARTPOSTGRESQLMSG']._serialized_end=23504
  _globals['_STARTCADVISORMSG']._serialized_start=23506
  _globals['_STARTCADVISORMSG']._serialized_end=23524
  _globals['_STARTNODEEXPORTERMSG']._serialized_start=23526
  _globals['_STARTNODEEXPORTERMSG']._serialized_end=23548
  _globals['_STARTGRAFANAMSG']._serialized_start=23550
  _globals['_STARTGRAFANAMSG']._serialized_end=23567
  _globals['_STARTPROMETHEUSMSG']._serialized_start=23569
  _globals['_STARTPROMETHEUSMSG']._serialized_end=23589
  _globals['_STARTPGADMINMSG']._serialized_start=23591
  _globals['_STARTPGADMINMSG']._serialized_end=23608
  _globals['_STARTNGINXMSG']._serialized_start=23610
  _globals['_STARTNGINXMSG']._serialized_end=23625
  _globals['_STARTFLASKMSG']._serialized_start=23627
  _globals['_STARTFLASKMSG']._serialized_end=23642
  _globals['_STARTDOCKERSTATSMANAGERMSG']._serialized_start=23644
  _globals['_STARTDOCKERSTATSMANAGERMSG']._serialized_end=23672
  _globals['_STARTDOCKERSTATSMANAGERTHREADMSG']._serialized_start=23674
  _globals['_STARTDOCKERSTATSMANAGERTHREADMSG']._serialized_end=23749
  _globals['_STARTDOCKERENGINEMSG']._serialized_start=23751
  _globals['_STARTDOCKERENGINEMSG']._serialized_end=23773
  _globals['_STOPPOSTGRESQLMSG']._serialized_start=23775
  _globals['_STOPPOSTGRESQLMSG']._serialized_end=23794
  _globals['_STOPCADVISORMSG']._serialized_start=23796
  _globals['_STOPCADVISORMSG']._serialized_end=23813
  _globals['_STOPNODEEXPORTERMSG']._serialized_start=23815
  _globals['_STOPNODEEXPORTERMSG']._serialized_end=23836
  _globals['_STOPGRAFANAMSG']._serialized_start=23838
  _globals['_STOPGRAFANAMSG']._serialized_end=23854
  _globals['_STOPPROMETHEUSMSG']._serialized_start=23856
  _globals['_STOPPROMETHEUSMSG']._serialized_end=23875
  _globals['_STOPPGADMINMSG']._serialized_start=23877
  _globals['_STOPPGADMINMSG']._serialized_end=23893
  _globals['_STOPNGINXMSG']._serialized_start=23895
  _globals['_STOPNGINXMSG']._serialized_end=23909
  _globals['_STOPFLASKMSG']._serialized_start=23911
  _globals['_STOPFLASKMSG']._serialized_end=23925
  _globals['_STOPDOCKERSTATSMANAGERMSG']._serialized_start=23927
  _globals['_STOPDOCKERSTATSMANAGERMSG']._serialized_end=23954
  _globals['_STOPDOCKERENGINEMSG']._serialized_start=23956
  _globals['_STOPDOCKERENGINEMSG']._serialized_end=23977
  _globals['_START5GCOREMANAGERSMSG']._serialized_start=23979
  _globals['_START5GCOREMANAGERSMSG']._serialized_end=24044
  _globals['_STOP5GCOREMANAGERSMSG']._serialized_start=24046
  _globals['_STOP5GCOREMANAGERSMSG']._serialized_end=24110
  _globals['_START5GCOREMANAGERMSG']._serialized_start=24112
  _globals['_START5GCOREMANAGERMSG']._serialized_end=24197
  _globals['_STOP5GCOREMANAGERMSG']._serialized_start=24199
  _globals['_STOP5GCOREMANAGERMSG']._serialized_end=24283
  _globals['_STOP5GCOREMSG']._serialized_start=24285
  _globals['_STOP5GCOREMSG']._serialized_end=24362
  _globals['_STOP5GCORESMSG']._serialized_start=24364
  _globals['_STOP5GCORESMSG']._serialized_end=24421
  _globals['_START5GCOREMSG']._serialized_start=24423
  _globals['_START5GCOREMSG']._serialized_end=24501
  _globals['_START5GCORESMSG']._serialized_start=24503
  _globals['_START5GCORESMSG']._serialized_end=24561
  _globals['_INIT5GCOREMSG']._serialized_start=24563
  _globals['_INIT5GCOREMSG']._serialized_end=24640
  _globals['_INIT5GCORESMSG']._serialized_start=24642
  _globals['_INIT5GCORESMSG']._serialized_end=24699
  _globals['_START5GCUMANAGERSMSG']._serialized_start=24701
  _globals['_START5GCUMANAGERSMSG']._serialized_end=24764
  _globals['_STOP5GCUMANAGERSMSG']._serialized_start=24766
  _globals['_STOP5GCUMANAGERSMSG']._serialized_end=24828
  _globals['_START5GCUMANAGERMSG']._serialized_start=24830
  _globals['_START5GCUMANAGERMSG']._serialized_end=24913
  _globals['_STOP5GCUMANAGERMSG']._serialized_start=24915
  _globals['_STOP5GCUMANAGERMSG']._serialized_end=24997
  _globals['_STOP5GCUMSG']._serialized_start=24999
  _globals['_STOP5GCUMSG']._serialized_end=25074
  _globals['_STOP5GCUSMSG']._serialized_start=25076
  _globals['_STOP5GCUSMSG']._serialized_end=25131
  _globals['_START5GCUMSG']._serialized_start=25133
  _globals['_START5GCUMSG']._serialized_end=25209
  _globals['_START5GCUSMSG']._serialized_start=25211
  _globals['_START5GCUSMSG']._serialized_end=25267
  _globals['_START5GDUMANAGERSMSG']._serialized_start=25269
  _globals['_START5GDUMANAGERSMSG']._serialized_end=25332
  _globals['_STOP5GDUMANAGERSMSG']._serialized_start=25334
  _globals['_STOP5GDUMANAGERSMSG']._serialized_end=25396
  _globals['_START5GDUMANAGERMSG']._serialized_start=25398
  _globals['_START5GDUMANAGERMSG']._serialized_end=25481
  _globals['_STOP5GDUMANAGERMSG']._serialized_start=25483
  _globals['_STOP5GDUMANAGERMSG']._serialized_end=25565
  _globals['_STOP5GDUMSG']._serialized_start=25567
  _globals['_STOP5GDUMSG']._serialized_end=25642
  _globals['_STOP5GDUSMSG']._serialized_start=25644
  _globals['_STOP5GDUSMSG']._serialized_end=25699
  _globals['_START5GDUMSG']._serialized_start=25701
  _globals['_START5GDUMSG']._serialized_end=25777
  _globals['_START5GDUSMSG']._serialized_start=25779
  _globals['_START5GDUSMSG']._serialized_end=25835
  _globals['_STOP5GUEMSG']._serialized_start=25837
  _globals['_STOP5GUEMSG']._serialized_end=25912
  _globals['_STOP5GUESMSG']._serialized_start=25914
  _globals['_STOP5GUESMSG']._serialized_end=25969
  _globals['_START5GUEMSG']._serialized_start=25971
  _globals['_START5GUEMSG']._serialized_end=26047
  _globals['_START5GUESMSG']._serialized_start=26049
  _globals['_START5GUESMSG']._serialized_end=26105
  _globals['_INIT5GUEMSG']._serialized_start=26107
  _globals['_INIT5GUEMSG']._serialized_end=26182
  _globals['_INIT5GUESMSG']._serialized_start=26184
  _globals['_INIT5GUESMSG']._serialized_end=26239
  _globals['_GET5GCOREMANAGERSINFOMSG']._serialized_start=26241
  _globals['_GET5GCOREMANAGERSINFOMSG']._serialized_end=26308
  _globals['_GET5GCUMANAGERSINFOMSG']._serialized_start=26310
  _globals['_GET5GCUMANAGERSINFOMSG']._serialized_end=26375
  _globals['_GET5GDUMANAGERSINFOMSG']._serialized_start=26377
  _globals['_GET5GDUMANAGERSINFOMSG']._serialized_end=26442
  _globals['_FIVEGCOREINFODTO']._serialized_start=26445
  _globals['_FIVEGCOREINFODTO']._serialized_end=26884
  _globals['_FIVEGCUINFODTO']._serialized_start=26886
  _globals['_FIVEGCUINFODTO']._serialized_end=26934
  _globals['_FIVEGDUINFODTO']._serialized_start=26936
  _globals['_FIVEGDUINFODTO']._serialized_end=27004
  _globals['_FIVEGCOREMANAGERSINFODTO']._serialized_start=27007
  _globals['_FIVEGCOREMANAGERSINFODTO']._serialized_end=27193
  _globals['_FIVEGCUMANAGERSINFODTO']._serialized_start=27196
  _globals['_FIVEGCUMANAGERSINFODTO']._serialized_end=27374
  _globals['_FIVEGDUMANAGERSINFODTO']._serialized_start=27377
  _globals['_FIVEGDUMANAGERSINFODTO']._serialized_end=27555
  _globals['_GET5GCOREMANAGERLOGSMSG']._serialized_start=27557
  _globals['_GET5GCOREMANAGERLOGSMSG']._serialized_end=27644
  _globals['_GET5GCUMANAGERLOGSMSG']._serialized_start=27646
  _globals['_GET5GCUMANAGERLOGSMSG']._serialized_end=27731
  _globals['_GET5GDUMANAGERLOGSMSG']._serialized_start=27733
  _globals['_GET5GDUMANAGERLOGSMSG']._serialized_end=27818
  _globals['_GET5GCORELOGSMSG']._serialized_start=27820
  _globals['_GET5GCORELOGSMSG']._serialized_end=27900
  _globals['_GET5GCULOGSMSG']._serialized_start=27902
  _globals['_GET5GCULOGSMSG']._serialized_end=27980
  _globals['_GET5GDULOGSMSG']._serialized_start=27982
  _globals['_GET5GDULOGSMSG']._serialized_end=28060
  _globals['_GET5GUELOGSMSG']._serialized_start=28062
  _globals['_GET5GUELOGSMSG']._serialized_end=28140
  _globals['_CLUSTERMANAGER']._serialized_start=28144
  _globals['_CLUSTERMANAGER']._serialized_end=45255
# @@protoc_insertion_point(module_scope)
